<?php
/**
 * Log user activity in the database
 *
 * @param mysqli $conn        Database connection
 * @param int|null $userId    ID of the user performing the action (null for system actions)
 * @param string $action      The specific action performed
 * @param string|null $description Additional details about the action
 */
function logActivity($conn, $userId, $action, $description = null) {
    $ipAddress = $_SERVER['REMOTE_ADDR'] ?? 'Unknown';
    $userAgent = $_SERVER['HTTP_USER_AGENT'] ?? 'Unknown';

    $sql = "INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent) 
            VALUES (?, ?, ?, ?, ?)";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("issss", $userId, $action, $description, $ipAddress, $userAgent);
    $stmt->execute();
}

/**
 * General User Actions
 */

// Log user login
function logUserLogin($conn, $userId) {
    logActivity($conn, $userId, 'User Login', 'User logged in successfully.');
}

// Log user logout
function logUserLogout($conn, $userId) {
    logActivity($conn, $userId, 'User Logout', 'User logged out.');
}

// Log profile update
function logProfileUpdate($conn, $userId) {
    logActivity($conn, $userId, 'Profile Updated', 'User updated their profile.');
}

// Log password change
function logPasswordChange($conn, $userId) {
    logActivity($conn, $userId, 'Password Changed', 'User changed their password.');
}

// Log avatar update
function logAvatarUpdate($conn, $userId) {
    logActivity($conn, $userId, 'Avatar Updated', 'User updated their profile picture.');
}

// Log account deletion
function logAccountDeletion($conn, $userId) {
    logActivity($conn, $userId, 'Account Deleted', 'User deleted their account.');
}

/**
 * Admin Actions
 */

// Log user approval
function logUserApproval($conn, $adminId, $userId) {
    logActivity($conn, $adminId, 'User Approved', "Admin approved user with ID $userId.");
}

// Log user rejection
function logUserRejection($conn, $adminId, $userId) {
    logActivity($conn, $adminId, 'User Rejected', "Admin rejected user with ID $userId.");
}

// Log user suspension
function logUserSuspension($conn, $adminId, $userId) {
    logActivity($conn, $adminId, 'User Suspended', "Admin suspended user with ID $userId.");
}

// Log role change
function logRoleChange($conn, $adminId, $userId, $newRole) {
    logActivity($conn, $adminId, 'Role Changed', "Admin changed role of user ID $userId to $newRole.");
}

// Log content deletion
function logContentDeletion($conn, $adminId, $contentType, $contentId) {
    logActivity($conn, $adminId, 'Content Deleted', "Admin deleted $contentType with ID $contentId.");
}

// Log system settings update
function logSystemSettingsUpdate($conn, $adminId) {
    logActivity($conn, $adminId, 'System Settings Updated', 'Admin updated system settings.');
}

// Log department management
function logDepartmentManagement($conn, $adminId, $action, $departmentName) {
    logActivity($conn, $adminId, 'Department Management', "Admin $action department: $departmentName.");
}

// Log year level management
function logYearLevelManagement($conn, $adminId, $action, $yearLevel) {
    logActivity($conn, $adminId, 'Year Level Management', "Admin $action year level: $yearLevel.");
}

/**
 * Faculty Actions
 */

// Log lesson management
function logLessonAction($conn, $facultyId, $action, $lessonId) {
    logActivity($conn, $facultyId, "Lesson $action", "Faculty $action lesson with ID $lessonId.");
}

// Log quiz management
function logQuizAction($conn, $facultyId, $action, $quizId) {
    logActivity($conn, $facultyId, "Quiz $action", "Faculty $action quiz with ID $quizId.");
}

// Log file upload
function logFileUpload($conn, $facultyId, $fileName) {
    logActivity($conn, $facultyId, 'File Uploaded', "Faculty uploaded file: $fileName.");
}

// Log quiz grading
function logQuizGrading($conn, $facultyId, $studentId, $quizId) {
    logActivity($conn, $facultyId, 'Quiz Graded', "Faculty graded quiz ID $quizId for student ID $studentId.");
}

/**
 * Student Actions
 */

// Log lesson interaction
function logLessonInteraction($conn, $studentId, $action, $lessonId) {
    logActivity($conn, $studentId, "Lesson $action", "Student $action lesson with ID $lessonId.");
}

// Log quiz interaction
function logQuizInteraction($conn, $studentId, $action, $quizId) {
    logActivity($conn, $studentId, "Quiz $action", "Student $action quiz with ID $quizId.");
}

// Log backpack management
function logBackpackAction($conn, $studentId, $action, $fileName) {
    logActivity($conn, $studentId, "Backpack $action", "Student $action file: $fileName.");
}

/**
 * System-Level Actions
 */

// Log error
function logError($conn, $userId, $errorMessage) {
    logActivity($conn, $userId, 'Error Logged', $errorMessage);
}

// Log unauthorized access attempt
function logUnauthorizedAccess($conn, $userId) {
    logActivity($conn, $userId, 'Unauthorized Access', 'User attempted to access a restricted area.');
}

// Log maintenance
function logMaintenance($conn, $adminId, $action) {
    logActivity($conn, $adminId, 'System Maintenance', "Admin performed: $action.");
}

// Log notification
function logNotification($conn, $userId, $action) {
    logActivity($conn, $userId, "Notification $action", "User $action a notification.");
}
