<?php
session_start();
// Check if the user is logged in and has the role of 'faculty'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'faculty') {
    header("Location: ../login.php");
    exit();
}

// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

include '../includes/dbcon.php'; // Include database connection

// Fetch classes for the dropdown
$classQuery = "SELECT id, class_name FROM classes"; // Adjust the table name as necessary
$classResult = $conn->query($classQuery);

// Define allowed file types
$allowedFileTypes = ['image', 'video', 'pdf', 'jpg', 'png', 'gif', 'bmp', 'mp4', 'avi', 'mov', 'mkv', 'mp3', 'wav', 'flac', 'doc', 'docx', 'ppt', 'pptx'];

// Handle file upload
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_FILES['material'])) {
    // Check if class_id is set
    if (!isset($_POST['class_id'])) {
        $_SESSION['error_message'] = "Class ID is required.";
        header("Location: downloadable_materials.php");
        exit();
    }
    
    $classId = $_POST['class_id']; // Get the selected class ID from the form
    $file = $_FILES['material'];
    $uploadDir = '../uploads/'; // Directory where files will be uploaded

    // Check if the upload directory is writable
    if (!is_dir($uploadDir) || !is_writable($uploadDir)) {
        $_SESSION['error_message'] = "Upload directory is not writable.";
        header("Location: downloadable_materials.php");
        exit();
    }

    $uploadFile = $uploadDir . basename($file['name']);
    
    // Check the file type
    $fileType = strtolower(pathinfo($uploadFile, PATHINFO_EXTENSION));
    if (!in_array($fileType, $allowedFileTypes)) {
        $_SESSION['error_message'] = "File type not allowed. Please upload a valid file.";
        header("Location: downloadable_materials.php");
        exit();
    }

    // Check if a file with the same class ID and file path already exists
    $stmt = $conn->prepare("SELECT * FROM materials WHERE class_id = ? AND file_path = ?");
    $stmt->bind_param("is", $classId, $uploadFile);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $_SESSION['error_message'] = "A file with the same name already exists in this class. Please change the name of the file and try again.";
    } else {
        // Check for errors
        if ($file['error'] !== UPLOAD_ERR_OK) {
            switch ($file['error']) {
                case UPLOAD_ERR_INI_SIZE:
                    $_SESSION['error_message'] = "The uploaded file exceeds the maximum file size limit.";
                    break;
                case UPLOAD_ERR_FORM_SIZE:
                    $_SESSION['error_message'] = "The uploaded file exceeds the maximum file size limit specified in the form.";
                    break;
                case UPLOAD_ERR_PARTIAL:
                    $_SESSION['error_message'] = "The uploaded file was only partially uploaded.";
                    break;
                case UPLOAD_ERR_NO_FILE:
                    $_SESSION['error_message'] = "No file was uploaded.";
                    break;
                default:
                    $_SESSION['error_message'] = "Unknown upload error.";
                    break;
            }
            header("Location: downloadable_materials.php");
            exit();
        }

        // Move the uploaded file to the designated directory
        if (move_uploaded_file($file['tmp_name'], $uploadFile)) {
            // Insert file information into the database
            $stmt = $conn->prepare("INSERT INTO materials (class_id, faculty_id, file_path, file_type, uploaded_at, created_at) VALUES (?, ?, ?, ?, NOW(), NOW())");
            $facultyId = $_SESSION['user_id']; // Assuming the logged-in user is the faculty
            
            $stmt->bind_param("iiss", $classId, $facultyId, $uploadFile, $fileType);
            
            if ($stmt->execute()) {
                // Log the activity
                $action = "Faculty uploaded a file";
                $description = "Uploaded file: " . htmlspecialchars(basename($uploadFile)) . " of type " . htmlspecialchars($fileType);
                $ipAddress = $_SERVER['REMOTE_ADDR'];
                $userAgent = $_SERVER['HTTP_USER_AGENT'];

                $logStmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent) VALUES (?, ?, ?, ?, ?)");
                $logStmt->bind_param("issss", $facultyId, $action, $description, $ipAddress, $userAgent);
                $logStmt->execute();
                $logStmt->close();

                $_SESSION['success_message'] = "File uploaded successfully: " . htmlspecialchars(basename($uploadFile));
            } else {
                $_SESSION['error_message'] = "Database error: " . $stmt->error;
            }
            
            $stmt->close();
        } else {
            $_SESSION['error_message'] = "Failed to move uploaded file.";
        }
    }
}

// Handle file deletion
if (isset($_GET['delete'])) {
    $id = intval($_GET['delete']);
    
    // Fetch the file path from the database
    $stmt = $conn->prepare("SELECT file_path FROM materials WHERE id = ?");
    $stmt->bind_param("i", $id);
    $stmt->execute();
    $result = $stmt->get_result();
    $file = $result->fetch_assoc();
    
    if ($file) {
        $filePath = $file['file_path'];
        
        // Check if the file exists before attempting to delete
        if (file_exists($filePath)) {
            if (unlink($filePath)) {
                // File deleted successfully
                $stmt = $conn->prepare("DELETE FROM materials WHERE id = ?");
                $stmt->bind_param("i", $id);
                $stmt->execute();
                
                // Log the activity
                $action = "Faculty deleted a file";
                $description = "Deleted file: " . htmlspecialchars(basename($filePath));
                $ipAddress = $_SERVER['REMOTE_ADDR'];
                $userAgent = $_SERVER['HTTP_USER_AGENT'];

                $logStmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent) VALUES (?, ?, ?, ?, ?)");
                $logStmt->bind_param("issss", $_SESSION['user_id'], $action, $description, $ipAddress, $userAgent);
                $logStmt->execute();
                $logStmt->close();

                $_SESSION['success_message'] = "File deleted successfully: " . htmlspecialchars(basename($filePath));
            } else {
                $_SESSION['error_message'] = "Failed to delete the file from the server.";
            }
        } else {
            $_SESSION['error_message'] = "File does not exist.";
        }
    } else {
        $_SESSION['error_message'] = "File not found.";
    }
    
    $stmt->close();
}

// Fetch classes with year levels and departments
$query = "SELECT c.id, c.class_name, yl.year_level, d.department_name 
          FROM classes c 
          LEFT JOIN year_levels yl ON c.year_level_id = yl.id 
          LEFT JOIN departments d ON c.department_id = d.id 
          ORDER BY c.class_name";

$resultt = $conn->query($query);

if (!$resultt) {
    die("Query failed: " . $conn->error);
}

// Fetch all materials uploaded by the logged-in faculty member
$query = "SELECT m.*, u.username, c.class_name, yl.year_level, d.department_name 
          FROM materials m 
          LEFT JOIN users u ON m.faculty_id = u.id 
          LEFT JOIN classes c ON m.class_id = c.id 
          LEFT JOIN year_levels yl ON c.year_level_id = yl.id 
          LEFT JOIN departments d ON c.department_id = d.id 
          WHERE m.faculty_id = ? 
          ORDER BY m.uploaded_at DESC";

$stmt = $conn->prepare($query);
$stmt->bind_param("i", $_SESSION['user_id']);
$stmt->execute();
$results = $stmt->get_result();

if (!$results) {
    die("Query failed: " . $conn->error);
}

// Check if an edit request has been made
if (isset($_GET['edit'])) {
    $id = intval($_GET['edit']);
    
    // Fetch the current material details along with names
    $stmt = $conn->prepare("SELECT m.class_id, c.class_name, d.department_name, yl.year_level 
                             FROM materials m 
                             LEFT JOIN classes c ON m.class_id = c.id 
                             LEFT JOIN departments d ON c.department_id = d.id 
                             LEFT JOIN year_levels yl ON c.year_level_id = yl.id 
                             WHERE m.id = ?");
    $stmt->bind_param("i", $id);
    $stmt->execute();
    $material = $stmt->get_result()->fetch_assoc();

    if ($material) {
        $currentClassId = $material['class_id'];
        $currentClassName = $material['class_name']; // Ensure this is set correctly
        $currentDepartmentName = $material['department _name'];
        $currentYearLevel = $material['year_level'];

        // Debugging: Log the fetched values
        error_log("Current Class ID: $currentClassId");
        error_log("Current Class Name: $currentClassName");
        error_log("Current Department Name: $currentDepartmentName");
        error_log("Current Year Level: $currentYearLevel");

    } else {
        $_SESSION['error_message'] = "Material not found.";
        header("Location: downloadable_materials.php");
        exit();
    }
}

// Handle class update
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['update_class'])) {
    $newClassId = $_POST['class_id'];
    $materialId = $_POST['material_id']; // Get the material ID from the form

    // Fetch the new class details
    $stmt = $conn->prepare("SELECT c.class_name, c.department_id, d.department_name, yl.year_level 
                             FROM classes c 
                             LEFT JOIN departments d ON c.department_id = d.id 
                             LEFT JOIN year_levels yl ON c.year_level_id = yl.id 
                             WHERE c.id = ?");
    $stmt->bind_param("i", $newClassId);
    $stmt->execute();
    $newClassDetails = $stmt->get_result()->fetch_assoc();

    if (!$newClassDetails) {
        $_SESSION['error_message'] = "New class not found.";
        header("Location: downloadable_materials.php");
        exit();
    }

    // Fetch old class details
    $stmt = $conn->prepare("SELECT c.class_name, d.department_name, yl.year_level 
    FROM materials m 
    LEFT JOIN classes c ON m.class_id = c.id 
    LEFT JOIN departments d ON c.department_id = d.id 
    LEFT JOIN year_levels yl ON c.year_level_id = yl.id 
    WHERE m.id = ?");
    $stmt->bind_param("i", $materialId);
    $stmt->execute();
    $oldClassDetails = $stmt->get_result()->fetch_assoc();

    $oldClassName = $oldClassDetails['class_name'];
    $oldDepartment = $oldClassDetails['department_name'];
    $oldYearLevel = $oldClassDetails['year_level'];
    $stmt->close();

    // Update the class in the database
    $stmt = $conn->prepare("UPDATE materials SET class_id = ? WHERE id = ?");
    $stmt->bind_param("ii", $newClassId, $materialId);

    if ($stmt->execute()) {
        // Log the activity using names
        $action = "Faculty updated class for material";
        $description = "Changed class from '$oldClassName' (Department: $oldDepartment, Year Level: $oldYearLevel) to '$newClassDetails[class_name]' (Department: $newClassDetails[department_name], Year Level: $newClassDetails[year_level])";
        $ipAddress = $_SERVER['REMOTE_ADDR'];
        $userAgent = $_SERVER['HTTP_USER_AGENT'];

        $logStmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent) VALUES (?, ?, ?, ?, ?)");
        $logStmt->bind_param("issss", $_SESSION['user_id'], $action, $description, $ipAddress, $userAgent);
        $logStmt->execute();
        $logStmt->close();

        $_SESSION['success_message'] = "Class updated successfully from '$oldClassName' (Department: $oldDepartment, Year Level: $oldYearLevel) to '$newClassDetails[class_name]' (Department: $newClassDetails[department_name], Year Level: $newClassDetails[year_level]).";
    } else {
        $_SESSION['error_message'] = "Database error: " . $stmt->error;
    }
    
    $stmt->close();
    header("Location: downloadable_materials.php");
    exit();
}
?> 
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manage Downloadable Materials</title>
    <link rel="icon" href="../assets/images/logo.ico"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.bundle.min.js"></script>
    <style>
        body {
            background-color: #f4f6f9;
        }
        .messages .alert {
            margin-bottom: 20px;
        }
        .container {
            margin-left: 250px;
            padding: 70px 30px;
            transition: margin-left 0.3s ease;
        }
        .sidebar {
            height: 100%;
            background-color: #6e8efb;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 65px !important;
            transition: width 0.3s ease;
        }

        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }

        .sidebar a:hover {
            background-color: #6e8efb;
        }

        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }

        .btn-primary:hover {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }
        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #6e8efb; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #f39c12; /* Hover effect for dropdown items */
        }
    </style>
</head>
<body>
    <!-- Header and Sidebar -->
    <?php include '../includes/faculty_header.php'; ?>
    <?php include '../includes/faculty_sidebar.php'; ?>

    <div class="container">
        <h1>Upload New Material</h1>
        <?php if (isset($_SESSION['error_message'])): ?>
            <div class="alert alert-danger">
                <?= htmlspecialchars($_SESSION['error_message']); ?>
                <?php unset($_SESSION['error_message']); ?>
            </div>
        <?php endif; ?>
        <?php if (isset($_SESSION['success_message'])): ?>
            <div class="alert alert-success">
                <?= htmlspecialchars($_SESSION['success_message']); ?>
                <?php unset($_SESSION['success_message']); ?>
            </div>
        <?php endif; ?>
        <form action="downloadable_materials.php" method="post" enctype="multipart/form-data">
            <label for="class_id">Select Class:</label>
            <select name="class_id" id="class_id" required>
                <?php while ($row = $resultt->fetch_assoc()): ?>
                    <option value="<?= $row['id']; ?>">
                        <?= htmlspecialchars($row['class_name'] . ' - ' . $row['year_level'] . ' (' . $row['department_name'] . ')'); ?>
                    </option>
                <?php endwhile; ?>
            </select>
            <br><br>
            <label for="material">Upload File:</label>
            <input type="file" name="material" id="material" required>
            <br><br>
            <p>Allowed file types: <strong>image, video, pdf, jpg, png, gif, bmp, mp4, avi, mov, mkv, mp3, wav, flac, doc, docx, ppt, pptx</strong></p>
            <p>Allowed maximum size: <strong>10 Mb</strong></p>
            <button type="submit" class="btn btn-primary">
                <i class="fas fa-upload"></i> Upload
            </button>
        </form>
        <hr>
        <?php if (isset($currentClassId)): ?>
            <h2>Edit Material Class</h2>
            <form action="downloadable_materials.php" method="post">
                <input type="hidden" name ="material_id" value="<?= $id; ?>">
                <label for="class_id">Select New Class:</label>
                <select name="class_id" id="class_id" required>
                    <?php
                    // Fetch all classes for the dropdown
                    $classQuery = "SELECT c.id, c.class_name, yl.year_level, d.department_name 
                                FROM classes c 
                                LEFT JOIN year_levels yl ON c.year_level_id = yl.id 
                                LEFT JOIN departments d ON c.department_id = d.id 
                                ORDER BY c.class_name";
                    $classResult = $conn->query($classQuery);
                    while ($row = $classResult->fetch_assoc()): ?>
                        <option value="<?= $row['id']; ?>" <?= ($row['id'] == $currentClassId) ? 'selected' : ''; ?>>
                            <?= htmlspecialchars($row['class_name'] . ' - ' . $row['year_level'] . ' (' . $row['department_name'] . ')'); ?>
                        </option>
                    <?php endwhile; ?>
                </select>
                <br><br>
                <button type="submit" name="update_class" class="btn btn-primary">
                    <i class="fas fa-save"></i> Save Changes
                </button>
            </form>
            <hr>
        <?php endif; ?>
        <h2>Your Uploaded Materials</h2>
        <table class="table">
            <thead>
                <tr>
                    <th>S.No.</th>
                    <th>File Name</th>
                    <th>Uploaded By</th>
                    <th>Class</th>
                    <th>Year Level</th>
                    <th>Department</th>
                    <th>Uploaded At</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php if ($results->num_rows > 0): ?>
                    <?php $serialNumber = 1; ?>
                    <?php while ($material = $results->fetch_assoc()): ?>
                        <tr>
                            <td><?= $serialNumber++; ?></td>
                            <td><?= htmlspecialchars(basename($material['file_path'])); ?></td>
                            <td><?= htmlspecialchars($material['username']); ?></td>
                            <td><?= htmlspecialchars($material['class_name']); ?></td>
                            <td><?= htmlspecialchars($material['year_level']); ?></td>
                            <td><?= htmlspecialchars($material['department_name']); ?></td>
                            <td><?= htmlspecialchars($material['uploaded_at']); ?></td>
                            <td>
                                <a href="download.php?id=<?= $material['id']; ?>" class="btn btn-success btn-sm" title="Download">
                                    <i class="fas fa-download"></i> Download
                                </a>
                                <a href="?edit=<?= $material['id']; ?>" class="btn btn-warning btn-sm" title="Edit">
                                    <i class="fas fa-edit"></i> Edit
                                </a>
                                <a href="?delete=<?= $material['id']; ?>" class="btn btn-danger btn-sm" onclick="return confirm('Are you sure you want to delete this file?');" title="Delete">
                                    <i class="fas fa-trash-alt"></i> Delete
                                </a>
                            </td>
                        </tr>
                    <?php endwhile; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="8" class="text-center">No materials uploaded yet.</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>
</body>
</html>