<?php
session_start();
include '../includes/dbcon.php'; // Include database connection

// Check if the user is logged in and has the role of 'faculty'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'faculty') {
    header("Location: ../login.php");
    exit();
}

// Check if the form was submitted
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Get the lesson ID
    $lesson_id = mysqli_real_escape_string($conn, $_POST['id']);
    $title = mysqli_real_escape_string($conn, $_POST['title']);
    $description = $_POST['description']; // Get the raw HTML content directly
    $class_id = mysqli_real_escape_string($conn, $_POST['class_id']);
    
    // Check if the lesson exists
    $lesson_check_query = "SELECT * FROM lessons WHERE id = ?";
    $stmt = $conn->prepare($lesson_check_query);
    $stmt->bind_param("i", $lesson_id);
    $stmt->execute();
    $lesson_result = $stmt->get_result();

    if ($lesson_result->num_rows === 0) {
        $_SESSION['error_message'] = "Lesson not found.";
        header("Location: manage_lessons.php");
        exit();
    }

    // Check for duplicates in the same class
    $duplicate_check_query = "SELECT * FROM lessons WHERE title = ? AND description = ? AND class_id = ? AND id != ?";
    $duplicate_stmt = $conn->prepare($duplicate_check_query);
    $duplicate_stmt->bind_param("ssii", $title, $description, $class_id, $lesson_id);
    $duplicate_stmt->execute();
    $duplicate_result = $duplicate_stmt->get_result();

    if ($duplicate_result->num_rows > 0) {
        $_SESSION['error_message'] = "A lesson with the same title and description already exists for this class.";
        header("Location: manage_lessons.php");
        exit();
    }

    // Update the lesson in the database
    $update_query = "UPDATE lessons SET title = ?, description = ?, class_id = ?, updated_at = NOW() WHERE id = ?";
    $stmt = $conn->prepare($update_query);
    $stmt->bind_param("ssii", $title, $description, $class_id, $lesson_id);

    if ($stmt->execute()) {
        $_SESSION['success_message'] = "Lesson updated successfully!";
    } else {
        $_SESSION['error_message'] = "Database error: " . $stmt->error;
    }

    $stmt->close();
    header("Location: manage_lessons.php");
    exit();
}

// Fetch the lesson to edit
if (!isset($_GET['id'])) {
    $_SESSION['error_message'] = "Invalid lesson ID.";
    header("Location: manage_lessons.php");
    exit();
}

$lesson_id = mysqli_real_escape_string($conn, $_GET['id']);
$lesson_query = "SELECT * FROM lessons WHERE id = ?";
$stmt = $conn->prepare($lesson_query);
$stmt->bind_param("i", $lesson_id);
$stmt->execute();
$lesson_result = $stmt->get_result();

if ($lesson_result->num_rows === 0) {
    $_SESSION['error_message'] = "Lesson not found.";
    header("Location: manage_lessons.php");
    exit();
}

$lesson = $lesson_result->fetch_assoc();

// Fetch classes with department name and year level
$class_query = "
    SELECT 
        classes.id AS class_id,
        classes.class_name,
        departments.department_name,
        year_levels.year_level,
        CONCAT(classes.class_name, ' (', departments.department_name, ' - ', year_levels.year_level, ')') AS full_class_name
    FROM 
        classes
    JOIN 
        departments ON classes.department_id = departments.id
    JOIN 
        year_levels ON classes.year_level_id = year_levels.id
    ORDER BY 
        classes.class_name
";
$class_result = mysqli_query($conn, $class_query);

// Check for errors in the query
if (!$class_result) {
    die("Query failed: " . mysqli_error($conn));
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Lesson</title>
    <link rel="icon" href="../assets/images/logo.ico">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/summernote@0.8.18/dist/summernote.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://code.jquery.com/ui/1.12.1/themes/base/jquery-ui.css">
    <style>
        body {
            background-color: #f4f6f9;
        }
        .messages .alert {
            margin-bottom: 20px;
            margin-left: 107px;
        }
        .container {
            margin-left: 250px;
            padding: 70px 30px;
            transition: margin-left 0.3s ease;
        }
        .card-header {
            background-color: #6e8efb;
            color: white;
        }
        .sidebar {
            height: 100%;
            background-color: #6e8efb;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 65px !important;
            transition: width 0.3s ease;
        }

        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }

        .sidebar a:hover {
            background-color: #6e8efb;
        }

        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }

        .btn-primary:hover {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }
        
        .editor {
            border: 1px solid #ccc;
            padding: 10px;
            border-radius: 5px;
            height: 200px; /* Set the height of the editor */
        }
    </style>
</head>
<body>
    <!-- Header and Sidebar -->
    <?php include '../includes/faculty_header.php'; ?>
    <?php include '../includes/faculty_sidebar.php'; ?>

    <div class="container mt-5">
        <h3 class="mb-4">Edit Lesson: <?= htmlspecialchars($lesson['title']); ?></h3>
        <form action="" method="POST" enctype="multipart/form-data">
            <input type="hidden" name="id" value="<?= $lesson['id']; ?>">
            <div class="mb-3">
                <label for="title" class="form-label">Lesson Title</label>
                <input type="text" class="form-control" id="title" name="title" value="<?= htmlspecialchars($lesson['title']); ?>" required>
            </div>
            <div class="mb-3">
                <label for="description" class="form-label">Description</label>
                <div id="editDescription" class="editor"><?= $lesson['description']; ?></div> <!-- No htmlspecialchars here -->
                <input type="hidden" name="description" id="editDescriptionInput" value="<?= htmlspecialchars($lesson['description']); ?>">
                <p><b>Note:</b> You can also use the images, videos, pdf, documents and PPT by using the copy link of downloadbale materials.</p>
            </div>
            <div class="mb-3">
                <label for="class_id" class="form-label">Select Class</label>
                <select class="form-select" id="class_id" name="class_id" required>
                    <option value="">Choose a class</option>
                    <?php while ($class_row = mysqli_fetch_assoc($class_result)): ?>
                        <option value="<?= $class_row['class_id'] ?>" <?= ($class_row['class_id'] == $lesson['class_id']) ? 'selected' : ''; ?>>
                            <?= htmlspecialchars($class_row['full_class_name']) ?>
                        </option>
                    <?php endwhile; ?>
                </select>
            </div>
            <button type="submit" class="btn btn-primary">Update Lesson</button>
            <a href="manage_lessons.php" class="btn btn-secondary">Cancel</a>
        </form>
    </div>

    <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
    <script src="https://code.jquery.com/ui/1.12.1/jquery-ui.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/summernote@0.8.18/dist/summernote.min.js"></script>
    <script>
        $(document).ready(function() {
            // Initialize Summernote and tooltips
            $('#editDescription').summernote({
                height: 200,
                toolbar: [
                    ['style', ['bold', 'italic', 'underline', 'clear']],
                    ['font', ['strikethrough', 'superscript', 'subscript']],
                    ['color', ['color']],
                    ['para', ['ul', 'ol', 'paragraph']],
                    ['insert', ['link', 'picture', 'video']],
                    ['view', ['fullscreen', 'codeview', 'help']]
                ],
                callbacks: {
                    onChange: function(contents, $editable) {
                        $('#editDescriptionInput').val(contents);
                    },
                    onImageUpload: function(files) {
                        for (let i = 0; i < files.length; i++) {
                            uploadImage(files[i]);
                        }
                    }
                }
            });

            // Set the initial content of the editor
            $('#editDescription').summernote('code', $('#editDescriptionInput').val());
        });

        function uploadImage(file) {
            let data = new FormData();
            data.append("file", file);
            $.ajax({
                url: 'upload_image.php',
                type: "POST",
                data: data,
                contentType: false,
                processData: false,
                success: function(url) {
                    $('#editDescription').summernote('insertImage', url);
                },
                error: function() {
                    console.error("Image upload failed.");
                }
            });
        }
    </script>
</body>
</html>