<?php
session_start();
// Check if the user is logged in and has the role of 'faculty'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'faculty') {
    header("Location: ../login.php");
    exit();
}

// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

include '../includes/dbcon.php'; // Include database connection

// Handle deletion
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['lesson_id'])) {
    $lesson_id = $_POST['lesson_id'];

    // Prepare the delete statement
    $delete_query = "DELETE FROM lessons WHERE id = ?";
    $stmt = $conn->prepare($delete_query);
    $stmt->bind_param("i", $lesson_id);

    if ($stmt->execute()) {
        $_SESSION['success_message'] = "Lesson deleted successfully.";
    } else {
        $_SESSION['error_message'] = "Error deleting lesson: " . $stmt->error;
    }

    $stmt->close();
    header("Location: manage_lessons.php");
    exit();
}

// Fetch lessons with related class, department, year level, and faculty information
$query = "
    SELECT 
        lessons.id AS lesson_id,
        lessons.title,
        lessons.description,
        lessons.class_id,
        lessons.media_files,
        classes.class_name,
        departments.department_name,
        year_levels.year_level,
        CONCAT(users.first_name, ' ', users.last_name) AS created_by,
        lessons.created_at,
        lessons.updated_at
    FROM 
        lessons
    JOIN 
        classes ON lessons.class_id = classes.id
    JOIN 
        departments ON classes.department_id = departments.id
    JOIN 
        year_levels ON classes.year_level_id = year_levels.id
    JOIN 
        users ON lessons.faculty_id = users.id
    ORDER BY 
        lessons.created_at DESC
";

$results = mysqli_query($conn, $query);

if (!$results) {
    die("Query failed: " . mysqli_error($conn));
}

// Fetch classes with department name and year level
$class_query = "
    SELECT 
        classes.id AS class_id,
        classes.class_name,
        departments.department_name,
        year_levels.year_level,
        CONCAT(classes.class_name, ' (', departments.department_name, ' - ', year_levels.year_level, ')') AS full_class_name
    FROM 
        classes
    JOIN 
        departments ON classes.department_id = departments.id
    JOIN 
        year_levels ON classes.year_level_id = year_levels.id
    ORDER BY 
        classes.class_name
";
$class_result = mysqli_query($conn, $class_query);

// Fetch previously uploaded materials for the logged-in faculty
$material_query = "SELECT * FROM materials WHERE faculty_id = ?";
$stmt = $conn->prepare($material_query);
$stmt->bind_param("i", $_SESSION['user_id']);
$stmt->execute();
$materials_result = $stmt->get_result();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manage Lessons</title>
    <link rel="icon" href="../assets/images/logo.ico"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/sceditor@3/minified/themes/default.min.css" />
    <style>
        body {
            background-color: #f4f6f9;
        }
        .messages .alert {
            margin-bottom: 20px;
            margin-left: 107px;
        }
        .container {
            margin-left: 250px;
            padding: 70px 30px;
            transition: margin-left 0.3s ease;
        }
        .card-header {
            background-color: #6e8efb;
            color: white;
        }
        .sidebar {
            height: 100%;
            background-color: #6e8efb;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 65px !important;
            transition: width 0.3s ease;
        }

        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }

        .sidebar a:hover {
            background-color: #6e8efb;
        }

        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }

        .btn-primary:hover {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }
    </style>
</head>
<body>
    <!-- Header and Sidebar -->
    <?php include '../includes/faculty_header.php'; ?>
    <?php include '../includes/faculty_sidebar.php'; ?>

    <div class="container mt-5">
        <h3>Manage Lessons</h3>

        <a href="add_lesson.php" class="btn btn-primary mb-3">Add New Lesson</a>

        <div class="messages">
            <?php if (isset($_SESSION['success_message'])): ?>
                <div class="alert alert-success" role="alert">
                    <?= htmlspecialchars($_SESSION['success_message']); ?>
                </div>
                <?php unset($_SESSION['success_message']); ?>
            <?php endif; ?>

            <?php if (isset($_SESSION['error_message'])): ?>
                <div class="alert alert-danger" role="alert">
                    <?= htmlspecialchars($_SESSION['error_message']); ?>
                </div>
                <?php unset($_SESSION['error_message']); ?>
            <?php endif; ?>
        </div>
        
        <table class="table table-bordered">
            <thead>
                <tr>
                    <th>S.No.</th>
                    <th>Title</th>
                    <th>Description</th>
                    <th>Class Name</th>
                    <th>Department Name</th>
                    <th>Year Level</th>
                    <th>Created By</th>
                    <th>Created At</th>
                    <th>Updated At</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php
                if (mysqli_num_rows($results) > 0) {
                    $counter = 1;
                    while ($row = mysqli_fetch_assoc($results)) {
                        // Get the description
                        $description = $row['description'];
                        // Remove HTML tags
                        $description = strip_tags($description);
                        // Remove URLs
                        $description = preg_replace('/\bhttps?:\/\/\S+\b/i', '', $description);
                        // Limit the description to 50 characters
                        $short_description = substr($description, 0, 50) . (strlen($description) > 50 ? '...' : '');

                        echo "<tr>
                            <td>{$counter}</td>
                            <td>{$row['title']}</td>
                            <td>{$short_description}</td>
                            <td>{$row['class_name']}</td>
                            <td>{$row['department_name']}</td>
                            <td>{$row['year_level']}</td>
                            <td>{$row['created_by']}</td>
                            <td>{$row['created_at']}</td>
                            <td>{$row['updated_at']}</td>
                            <td>
                                <a href='edit_lesson.php?id={$row['lesson_id']}' class='btn btn-warning btn-sm'>Edit</a>
                                <button class='btn btn-danger btn-sm' data-bs-toggle='modal' data-bs-target='#deleteModal' onclick='setLessonId({$row['lesson_id']})'>Delete</button>
                            </td>
                        </tr>";
                        $counter++;
                    }
                } else {
                    echo "<tr><td colspan='10' class='text-center'>No lessons found</td></tr>";
                }
                ?>
            </tbody>
        </table>
    </div>

    <!-- Delete Modal -->
    <div class="modal fade" id="deleteModal" tabindex="-1" aria-labelledby="deleteModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="deleteModalLabel">Confirm Delete</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    Are you sure you want to delete this lesson?
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                    <form id="deleteForm" method="POST" action="">
                        <input type="hidden" name="lesson_id" id="lesson_id" value="">
                        <button type="submit" class="btn btn-danger">Delete</button>
                    </form>
                </div>
            </div>
        </div>
    </div>

    <script>
        function setLessonId(lessonId) {
            document.getElementById('lesson_id').value = lessonId;
        }
    </script>

<script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>