<?php
session_start();
// Check if the user is logged in and has the role of 'faculty'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'faculty') {
    header("Location: ../login.php");
    exit();
}

// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

include '../includes/dbcon.php'; // Include database connection

// Check connection
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Get the logged-in faculty ID
$created_by = $_SESSION['user_id'];

// Initialize message variables
$message = '';
$message_type = '';

// Function to check for duplicates
function checkDuplicate($conn, $title, $description, $class_id, $quiz_id = null) {
    if ($quiz_id) {
        // Check for duplicates excluding the current quiz
        $stmt = $conn->prepare("SELECT COUNT(*) FROM quizzes WHERE title=? AND description=? AND class_id=? AND id!=?");
        $stmt->bind_param("ssii", $title, $description, $class_id, $quiz_id);
    } else {
        // Check for duplicates including all quizzes
        $stmt = $conn->prepare("SELECT COUNT(*) FROM quizzes WHERE title=? AND description=? AND class_id=?");
        $stmt->bind_param("ssi", $title, $description, $class_id);
    }

    $stmt->execute();
    $stmt->bind_result($count);
    $stmt->fetch();
    $stmt->close();

    return $count > 0;
}

// Function to add a quiz
function addQuiz($conn, $title, $description, $num_questions, $duration, $due_date, $class_id, $created_by) {
    // Check for duplicates
    if (checkDuplicate($conn, $title, $description, $class_id)) {
        return ['message' => 'A quiz with the same title, description, and class already exists.', 'type' => 'danger'];
    }

    // Prepare the SQL statement
    $stmt = $conn->prepare("INSERT INTO quizzes (title, description, num_questions, duration, due_date, class_id, created_by, created_at, updated_at) VALUES (?, ?, ?, ?, ?, ?, ?, NOW(), NOW())");
    if (!$stmt) {
        return ['message' => 'Error preparing statement: ' . $conn->error, 'type' => 'danger'];
    }

    // Bind parameters
    $stmt->bind_param("ssiisii", $title, $description, $num_questions, $duration, $due_date, $class_id, $created_by);

    // Execute the statement
    if ($stmt->execute()) {
        $stmt->close();
        return ['message' => 'Quiz saved successfully!', 'type' => 'success'];
    } else {
        $stmt->close();
        return ['message' => 'Error: ' . $stmt->error, 'type' => 'danger'];
    }
}

// Function to edit a quiz
function editQuiz($conn, $quiz_id, $title, $description, $num_questions, $duration, $due_date, $class_id) {
    // Check for duplicates
    if (checkDuplicate($conn, $title, $description, $class_id, $quiz_id)) {
        return ['message' => 'A quiz with the same title, description, and class already exists.', 'type' => 'danger'];
    }

    // Prepare the SQL statement
    $stmt = $conn->prepare("UPDATE quizzes SET title=?, description=?, num_questions=?, duration=?, due_date=?, class_id=?, updated_at=NOW() WHERE id=?");
    if (!$stmt) {
        return ['message' => 'Error preparing statement: ' . $conn->error, 'type' => 'danger'];
    }

    // Bind parameters
    $stmt->bind_param("ssiisii", $title, $description, $num_questions, $duration, $due_date, $class_id, $quiz_id);

    // Execute the statement
    if ($stmt->execute()) {
        $stmt->close();
        return ['message' => 'Quiz updated successfully!', 'type' => 'success'];
    } else {
        $stmt->close();
        return ['message' => 'Error: ' . $stmt->error, 'type' => 'danger'];
    }
}

// Handle form submissions for adding or updating quizzes
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $title = $_POST['title'];
    $description = $_POST['description'];
    $duration = $_POST['duration'];
    $num_questions = $_POST['num_questions'];
    $due_date = $_POST['due_date'];
    $class_id = $_POST['class_id']; // Get class_id from the form

    // Validate and format the due_date
    $formatted_due_date = date('Y-m-d H:i:s', strtotime($due_date));
    
    // Check if the formatted date is valid
    if ($formatted_due_date === false) {
        // Handle the error (e.g., set an error message)
        $message = 'Invalid due date format.';
        $message_type = 'danger';
    } else {
        // Proceed with the edit or add operation
        if (isset($_POST['quiz_id']) && !empty($_POST['quiz_id'])) {
            // Edit existing quiz
            $quiz_id = $_POST['quiz_id'];
            $result = editQuiz($conn, $quiz_id, $title, $description, $num_questions, $duration, $formatted_due_date, $class_id);
        } else {
            // Add new quiz
            $result = addQuiz($conn, $title, $description, $num_questions, $duration, $formatted_due_date, $class_id, $created_by);
        }

        $message = $result['message'];
        $message_type = $result['type'];
    }
}

// Handle quiz deletion
if (isset($_GET['delete'])) {
    $quiz_id = $_GET['delete'];
    $stmt = $conn->prepare("DELETE FROM quizzes WHERE id=? AND created_by=?");
    $stmt->bind_param("ii", $quiz_id, $created_by);
    if ($stmt->execute()) {
        $message = 'Quiz deleted successfully!';
        $message_type = 'success';
    } else {
        $message = 'Error: ' . $stmt->error;
        $message_type = 'danger';
    }
    $stmt->close();
}

// Fetch quizzes created by the logged-in faculty member
$results = $conn->query("SELECT q.*, 
                                CONCAT(c.class_name, ' (', d.department_name, ' - ', yl.year_level, ')') AS class_name, 
                                u.username AS created_by_username, 
                                d.department_name, 
                                yl.year_level 
                         FROM quizzes q 
                         LEFT JOIN classes c ON q.class_id = c.id 
                         LEFT JOIN departments d ON c.department_id = d.id 
                         LEFT JOIN year_levels yl ON c.year_level_id = yl.id 
                         LEFT JOIN users u ON q.created_by = u.id 
                         WHERE q.created_by = $created_by
                         ORDER BY q.due_date DESC");

// Fetch classes for the dropdown
$classes_result = $conn->query("SELECT c.id, 
                                 CONCAT(c.class_name, ' (', d.department_name, ' - ', yl.year_level, ')') AS class_name 
                                 FROM classes c 
                                 JOIN departments d ON c.department_id = d.id 
                                 JOIN year_levels yl ON c.year_level_id = yl.id");
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Quiz Management</title>
    <link rel="icon" href="../assets/images/logo.ico"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f4f6f9;
        }
        .container {
            margin-left: 250px;
            padding: 70px 30px;
            transition: margin-left 0.3s ease;
        }
        .sidebar {
            height: 100%;
            background-color: #6e8efb;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 65px !important;
            transition: width 0.3s ease;
        }
        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }
        .sidebar a:hover {
            background-color: #6e8efb;
        }
        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }
        .btn-primary:hover {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }
        .success {
            background-color: #d4edda; /* Light green */
        }
        .warning {
            background-color: #fff3cd; /* Light yellow */
        }
        .danger {
            background-color: #f8d7da; /* Light red */
        }
    </style>
</head>
<body>
    <!-- Header and Sidebar -->
    <?php include '../includes/faculty_header.php'; ?>
    <?php include '../includes/faculty_sidebar.php'; ?>
    <div class="container">
        <h1>Quiz Management</h1>
        
        <!-- Display success or error message -->
        <?php if ($message): ?>
            <div class="alert alert-<?php echo $message_type; ?>" role="alert">
                <?php echo htmlspecialchars($message); ?>
            </div>
        <?php endif; ?>

        <button class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#addQuizModal">Add Quiz</button>

        <h2>Existing Quizzes</h2>
        <table class="table table-striped">
            <thead>
                <tr>
                    <th>S.No.</th>
                    <th>Title</th>
                    <th>Description</th>
                    <th>Number of Questions</th>
                    <th>Duration</th>
                    <th>Due Date</th>
                    <th>Class</th>
                    <th>Created By</th>
                    <th>Created At</th>
                    <th>Updated At</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php if ($results->num_rows > 0): ?>
                    <?php $serial_number = 1; // Initialize serial number ?>
                    <?php $currentDate = new DateTime(); // Current date ?>
                    <?php while ($row = $results->fetch_assoc()): ?>
                        <?php
                            $dueDate = new DateTime($row['due_date']);
                            $interval = $currentDate->diff($dueDate);
                            
                            // Determine the class based on the due date
                            if ($dueDate < $currentDate) {
                                $class = 'danger'; // Overdue
                            } elseif ($interval->days <= 1) {
                                $class = 'danger'; // Due today
                            } elseif ($interval->days <= 3) {
                                $class = 'warning'; // Due in 3 days
                            } else {
                                $class = 'success'; // More than 3 days away
                            }
                            ?>
                            <tr class="<?= $class; ?>">
                                <td><?php echo $serial_number++; ?></td> <!-- Display serial number -->
                                <td><?php echo htmlspecialchars($row['title']); ?></td>
                                <td><?php echo htmlspecialchars($row['description']); ?></td>
                                <td><?php echo htmlspecialchars($row['num_questions']); ?></td>
                                <td><?php echo htmlspecialchars($row['duration']); ?> minutes</td>
                                <td><?php echo htmlspecialchars(date('Y-m-d H:i', strtotime($row['due_date']))); ?> UTC</td>
                                <td><?php echo htmlspecialchars($row['class_name']); ?></td>
                                <td><?php echo htmlspecialchars($row['created_by_username']); ?></td>
                                <td><?php echo htmlspecialchars($row['created_at']); ?> UTC</td>
                                <td><?php echo htmlspecialchars($row['updated_at']); ?> UTC</td>
                                <td>
                                    <button class="btn btn-warning" onclick="editQuiz(<?php echo $row['id']; ?>, '<?php echo addslashes(htmlspecialchars($row['title'])); ?>', '<?php echo addslashes(htmlspecialchars($row['description'])); ?>', <?php echo $row['num_questions']; ?>, <?php echo $row['duration']; ?>, '<?php echo htmlspecialchars(date('Y-m-d\TH:i', strtotime($row['due_date']))); ?>', <?php echo $row['class_id']; ?>)"><i class="fas fa-edit"></i> Edit</button>
                                    <button class="btn btn-danger" onclick="confirmDelete(<?php echo $row['id']; ?>)"><i class="fas fa-trash"></i> Delete</button>
                                    <a href="quiz_details.php?quiz_id=<?php echo $row['id']; ?>" class="btn btn-info"><i class="fas fa-eye"></i> View Details</a>
                                    <a href="quiz_results.php?quiz_id=<?php echo $row['id']; ?>" class="btn btn-success"><i class="fas fa-chart-bar"></i> Quiz Results</a>
                                </td>
                            </tr>
                    <?php endwhile; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="11" class="text-center">No Quizzes Found</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <!-- Modal for adding quizzes -->
    <div class="modal fade" id="addQuizModal" tabindex="-1" aria-labelledby="addQuizModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="addQuizModalLabel">Add Quiz</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <form method="POST" action="">
                        <div class="mb-3">
                            <label for="title" class="form-label">Title</label>
                            <input type="text" class="form-control" id="title" name="title" required>
                        </div>
                        <div class="mb-3">
                            <label for="description" class="form-label">Description</label>
                            <textarea class="form-control" id="description" name="description" required></textarea>
                        </div>
                        <div class="mb-3">
                            <label for="num_questions" class="form-label">Number of Questions</label>
                            <input type="number" class="form-control" id="num_questions" name="num_questions" required>
                        </div>
                        <div class="mb-3">
                            <label for="duration" class="form-label">Duration (in minutes)</label>
                            <input type="number" class="form-control" id="duration" name="duration" required>
                        </div>
                        <div class="mb-3">
                            <label for="due_date" class="form-label">Due Date</label>
                            <input type="datetime-local" class="form-control" id="due_date" name="due_date" required>
                        </div>
                        <div class="mb-3">
                            <label for="class_id" class="form-label">Class </label>
                            <select class="form-select" id="class_id" name="class_id" required>
                                <option value="">Select Class</option>
                                <?php while ($class = $classes_result->fetch_assoc()): ?>
                                    <option value="<?php echo $class['id']; ?>"><?php echo htmlspecialchars($class['class_name']); ?></option>
                                <?php endwhile; ?>
                            </select>
                        </div>
                        <input type="hidden" name="quiz_id" id="quiz_id">
                        <button type="submit" class="btn btn-primary">Save Quiz</button>
                    </form>
                </div>
            </div>
        </div>
    </div>

    <!-- Modal for editing quizzes -->
    <div class="modal fade" id="editQuizModal" tabindex="-1" aria-labelledby="editQuizModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="editQuizModalLabel">Edit Quiz</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <form method="POST" action="">
                        <div class="mb-3">
                            <label for="edit_title" class="form-label">Title</label>
                            <input type="text" class="form-control" id="edit_title" name="title" required>
                        </div>
                        <div class="mb-3">
                            <label for="edit_description" class="form-label">Description</label>
                            <textarea class="form-control" id="edit_description" name="description" required></textarea>
                        </div>
                        <div class="mb-3">
                            <label for="edit_num_questions" class="form-label">Number of Questions</label>
                            <input type="number" class="form-control" id="edit_num_questions" name="num_questions" required>
                        </div>
                        <div class="mb-3">
                            <label for="edit_duration" class="form-label">Duration (in minutes)</label>
                            <input type="number" class="form-control" id="edit_duration" name="duration" required>
                        </div>
                        <div class="mb-3">
                            <label for="edit_due_date" class="form-label">Due Date</label>
                            <input type="datetime-local" class="form-control" id="edit_due_date" name="due_date" required>
                        </div>
                        <div class="mb-3">
                            <label for="edit_class_id" class="form-label">Class</label>
                            <select class="form-select" id="edit_class_id" name="class_id" required>
                                <option value="">Select Class</option>
                                <?php 
                                // Reset the classes result pointer to the beginning
                                $classes_result->data_seek(0); 
                                while ($class = $classes_result->fetch_assoc()): ?>
                                    <option value="<?php echo $class['id']; ?>"><?php echo htmlspecialchars($class['class_name']); ?></option>
                                <?php endwhile; ?>
                            </select>
                        </div>
                        <input type="hidden" name="quiz_id" id="edit_quiz_id">
                        <button type="submit" class="btn btn-primary">Update Quiz</button>
                    </form>
                </div>
            </div>
        </div>
    </div>

    <!-- Modal for delete confirmation -->
    <div class="modal fade" id="deleteQuizModal" tabindex="-1" aria-labelledby="deleteQuizModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="deleteQuizModalLabel">Delete Quiz</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <p>Are you sure you want to delete this quiz?</p>
                </div>
                <div class="modal-footer">
                    <form id="deleteQuizForm" method="GET" action="">
                        <input type="hidden" name="delete" id="quiz_id_to_delete">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                        <button type="submit" class="btn btn-danger">Delete</button>
                    </form>
                </div>
            </div>
        </div>
    </div>

    <script>
        function editQuiz(id, title, description, num_questions, duration, due_date, classId) {
            document.getElementById('edit_quiz_id').value = id;
            document.getElementById('edit_title').value = title;
            document.getElementById('edit_description').value = description;
            document.getElementById('edit_num_questions').value = num_questions;
            document.getElementById('edit_duration').value = duration;
            document.getElementById('edit_due_date').value = due_date;
            document.getElementById('edit_class_id').value = classId;
            var editModal = new bootstrap.Modal(document.getElementById('editQuizModal'));
            editModal.show();
        }

        function confirmDelete(quizId) {
            document.getElementById('quiz_id_to_delete').value = quizId;
            var deleteModal = new bootstrap.Modal(document.getElementById('deleteQuizModal'));
            deleteModal.show();
        }
    </script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>