<?php
session_start();
include '../includes/dbcon.php'; // Include database connection

// Check if the user is logged in and has the role of 'faculty'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'faculty') {
    header("Location: ../login.php");
    exit();
}

// Get the quiz ID from the URL
$quiz_id = isset($_GET['quiz_id']) ? intval($_GET['quiz_id']) : 0;

// Initialize message variables
$message = '';
$message_type = '';

// Function to fetch quiz questions
function fetchQuizQuestions($conn, $quiz_id) {
    $stmt = $conn->prepare("SELECT * FROM quiz_questions WHERE quiz_id=?");
    $stmt->bind_param("i", $quiz_id);
    $stmt->execute();
    return $stmt->get_result();
}

// Handle adding a question
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['add_question'])) {
    $question_text = $_POST['question_text'];
    $question_type = $_POST['question_type'];
    $explanation = $_POST['explanation'];
    $created_by = $_SESSION['user_id'];
    $image_path = null;

    $allowed_extensions = ['jpg', 'jpeg', 'png', 'gif', 'bmp', 'webp'];
    if (!in_array($imageFileType, $allowed_extensions)) {
        $message = "Sorry, only JPG, JPEG, PNG, GIF, BMP, and WEBP files are allowed.";
        $message_type = 'danger';
    }

    // Handle image upload
    if (isset($_FILES['image']) && $_FILES['image']['error'] == UPLOAD_ERR_OK) {
        $target_dir = "uploads/"; // Ensure this directory exists and is writable
        $target_file = $target_dir . basename($_FILES["image"]["name"]);
        $imageFileType = strtolower(pathinfo($target_file, PATHINFO_EXTENSION));

        // Check if the file is an actual image
        $check = getimagesize($_FILES["image"]["tmp_name"]);
        if ($check !== false) {
            // Move the uploaded file to the target directory
            if (move_uploaded_file($_FILES["image"]["tmp_name"], $target_file)) {
                $image_path = $target_file; // Store the path for database insertion
            } else {
                $message = "Sorry, there was an error uploading your file.";
                $message_type = 'danger';
            }
        } else {
            $message = "File is not an image.";
            $message_type = 'danger';
        }
    }

    // Prepare and execute the database insert
    $stmt = $conn->prepare("INSERT INTO quiz_questions (quiz_id, question_text, question_type, explanation, image_path, created_by) VALUES (?, ?, ?, ?, ?, ?)");

    if ($stmt->execute([$quiz_id, $question_text, $question_type, $explanation, $image_path, $created_by])) {
        $question_id = $stmt->insert_id; // Get the ID of the newly inserted question

        // Insert options if the question type is multiple-choice or checkbox
        if ($question_type === 'multiple-choice' || $question_type === 'checkbox') {
            $options = $_POST['options'];
            $is_correct = isset($_POST['is_correct']) ? $_POST['is_correct'] : [];

            // Ensure at least one option is marked as correct
            if (empty($is_correct)) {
                $message = 'Please mark at least one option as correct.';
                $message_type = 'danger';
            } else {
                foreach ($options as $index => $option_text) {
                    $correct = in_array($index + 1, $is_correct) ? 1 : 0; // Determine if the option is correct
                    $option_stmt = $conn->prepare("INSERT INTO quiz_options (question_id, option_text, is_correct) VALUES (?, ?, ?)");
                    $option_stmt->bind_param("isi", $question_id, $option_text, $correct);
                    $option_stmt->execute();
                    $option_stmt->close();
                }
                $message = 'Question and options added successfully!';
                $message_type = 'success';
            }
        } elseif ($question_type === 'true-false') {
            // Insert True/False options
            $true_option = "True";
            $false_option = "False";

            // Insert True option
            $option_stmt = $conn->prepare("INSERT INTO quiz_options (question_id, option_text, is_correct) VALUES (?, ?, ?)");
            $option_stmt->bind_param("isi", $question_id, $true_option, $is_correct[0] ?? 0); // Default to 0 if not set
            $option_stmt->execute();

            // Insert False option
            $option_stmt->bind_param("isi", $question_id, $false_option, $is_correct[1] ?? 0); // Default to 0 if not set
            $option_stmt->execute();

            $option_stmt->close();
            $message = 'Question added successfully with True/False options!';
            $message_type = 'success';
        }
    } else {
        $message = 'Error: ' . $stmt->error;
        $message_type = 'danger';
    }
    $stmt->close();
}

// Fetch quiz questions
$questions = fetchQuizQuestions($conn, $quiz_id);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Quiz Details</title>
    <link rel="icon" href="../assets/images/logo.ico"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f4f6f9;
        }
        .container {
            margin-left: 250px;
            padding: 70px 30px;
            transition: margin-left 0.3s ease;
        }
        .sidebar {
            height: 100%;
            background-color: #6e8efb;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 65px !important;
            transition: width 0.3s ease;
        }
        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }
        .sidebar a:hover {
            background-color: #6e8efb;
        }
        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }
        .btn-primary:hover {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }
    </style>
</head>
<body>
    <!-- Header and Sidebar -->
    <?php include '../includes/faculty_header.php'; ?>
    <?php include '../includes/faculty_sidebar.php'; ?>

    <div class="container">
        <h1>Quiz Details</h1>

        <!-- Display success or error message -->
        <?php if ($message): ?>
            <div class="alert alert-<?php echo $message_type; ?>" role="alert">
                <?php echo htmlspecialchars($message); ?>
            </div>
        <?php endif; ?>

        <!-- Existing Questions Section -->
        <h2>Existing Questions</h2>
        <table class="table table-striped">
            <thead>
                <tr>
                    <th>S.No.</th>
                    <th>Question Text</th>
                    <th>Question Type</th>
                    <th>Options</th>
                    <th>Image Path</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php if ($questions->num_rows > 0): ?>
                    <?php 
                    $serial_number = 1; // Initialize serial number
                    while ($question = $questions->fetch_assoc()): ?>
                        <tr>
                            <td><?php echo $serial_number++; ?></td> <!-- Display serial number -->
                            <td><?php echo htmlspecialchars($question['question_text']); ?></td>
                            <td><?php echo htmlspecialchars($question['question_type']); ?></td>
                            <td>
                                <?php
                                // Fetch options for the current question
                                $option_stmt = $conn->prepare("SELECT * FROM quiz_options WHERE question_id=?");
                                $option_stmt->bind_param("i", $question['id']);
                                $option_stmt->execute();
                                $options_result = $option_stmt->get_result();
                                while ($option = $options_result->fetch_assoc()) {
                                    echo htmlspecialchars($option['option_text']) . ($option['is_correct'] ? ' (Correct)' : '') . '<br>';
                                }
                                $option_stmt->close();
                                ?>
                            </td>
                            <td>
                                <?php echo $question['image_path'] ? htmlspecialchars($question['image_path']) : '-'; ?>
                            </td>
                            <td>
                                <a href="edit_question.php?question_id=<?php echo $question['id']; ?>&quiz_id=<?php echo $quiz_id; ?>" class=" btn btn-primary">Edit</a>
                                <a href="delete_question.php?question_id=<?php echo $question['id']; ?>&quiz_id=<?php echo $quiz_id; ?>" class="btn btn-danger">Delete</a>
                            </td>
                        </tr>
                    <?php endwhile; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="6">No questions found.</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>

        <h2>Add Question</h2>
        <form method="POST" action="" id="questionForm" enctype="multipart/form-data">
            <div class="mb-3">
                <label for="question_text" class="form-label">Question Text</label>
                <input type="text" class="form-control" id="question_text" name="question_text" required>
            </div>
            <div class="mb-3">
                <label for="question_type" class="form-label">Question Type</label>
                <select class="form-select" id="question_type" name="question_type" required onchange="toggleOptions()">
                    <option value="multiple-choice">Multiple Choice</option>
                    <option value="checkbox">Checkbox</option>
                    <option value="true-false">True/False</option>
                </select>
            </div>
            <div id="optionsContainer" class="mb-3">
                <label class="form-label">Options</label>
                <div id="options">
                    <!-- Default options for multiple choice -->
                    <div class="input-group mb-2">
                        <input type="text" class="form-control" name="options[]" placeholder="Option 1" required>
                        <input type="checkbox" name="is_correct[]" value="1"> Correct
                    </div>
                    <div class="input-group mb-2">
                        <input type="text" class="form-control" name="options[]" placeholder="Option 2" required>
                        <input type="checkbox" name="is_correct[]" value="2"> Correct
                    </div>
                    <div class="input-group mb-2">
                        <input type="text" class="form-control" name="options[]" placeholder="Option 3" required>
                        <input type="checkbox" name="is_correct[]" value="3"> Correct
                    </div>
                    <div class="input-group mb-2">
                        <input type="text" class="form-control" name="options[]" placeholder="Option 4" required>
                        <input type="checkbox" name="is_correct[]" value="4"> Correct
                    </div>
                </div>
                <button type="button" class="btn btn-secondary" onclick="addOption()">Add Option</button>
            </div>
            <div class="mb-3">
                <label for="explanation" class="form-label">Explanation</label>
                <textarea class="form-control" id="explanation" name="explanation"></textarea>
            </div>
            <div class="mb-3">
                <label for="image" class="form-label">Upload Image</label>
                <input type="file" class="form-control" id="image" name="image" accept="image/*">
            </div>
            <input type="hidden" name="add_question" value="1">
            <button type="submit" class="btn btn-primary">Add Question</button>
        </form>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        function toggleOptions() {
            const questionType = document.getElementById('question_type').value;
            const optionsContainer = document.getElementById('optionsContainer');
            const optionsDiv = document.getElementById('options');

            // Clear existing options
            optionsDiv.innerHTML = '';

            if (questionType === 'true-false') {
                optionsContainer.style.display = 'block';
                optionsDiv.innerHTML = `
                    <div class="input-group mb-2">
                        <input type="text" class="form-control" name="options[]" value="True" required>
                        <input type="checkbox" name="is_correct[]" value="1"> Correct
                    </div>
                    <div class="input-group mb-2">
                        <input type="text" class="form-control" name="options[]" value="False" required>
                        <input type="checkbox" name="is_correct[]" value="2"> Correct
                    </div>
                `;
            } else {
                optionsContainer.style.display = 'block';
                for (let i = 1; i <= 4; i++) {
                    optionsDiv.innerHTML += `
                        <div class="input-group mb-2">
                            <input type="text" class="form-control" name="options[]" placeholder="Option ${i}" required>
                            <input type="checkbox" name="is_correct[]" value="${i}"> Correct
                        </div>
                    `;
                }
            }
        }

        function addOption() {
            const optionsDiv = document.getElementById('options');
            const optionCount = optionsDiv.children.length + 1;
            const newOption = document.createElement('div');
            newOption.className = 'input-group mb-2';
            newOption.innerHTML = `
                <input type="text" class="form-control" name="options[]" placeholder="Option ${optionCount}" required>
                <input type="checkbox" name="is_correct[]" value="${optionCount}"> Correct
            `;
            optionsDiv.appendChild(newOption);
        }
    </script>
</body>
</html>