<?php
session_start();
// Check if the user is logged in and has the role of 'faculty'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'faculty') {
    header("Location: ../login.php");
    exit();
}

// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

include '../includes/dbcon.php'; // Include database connection

// Function to log activity
function logActivity($conn, $userId, $action, $description) {
    $ipAddress = $_SERVER['REMOTE_ADDR'];
    $userAgent = $_SERVER['HTTP_USER_AGENT'];
    
    $stmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent, created_at) VALUES (?, ?, ?, ?, ?, NOW())");
    $stmt->bind_param("issss", $userId, $action, $description, $ipAddress, $userAgent);
    $stmt->execute();
    $stmt->close();
}

// Fetch classes along with their departments and year levels for the dropdown
$classQuery = "
    SELECT c.id, c.class_name, d.department_name, yl.year_level 
    FROM classes c 
    LEFT JOIN departments d ON c.department_id = d.id 
    LEFT JOIN year_levels yl ON c.year_level_id = yl.id
";
$classResult = $conn->query($classQuery);

// Handle assignment creation
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['create_assignment'])) {
    $classId = $_POST['class_id'];
    $title = $_POST['title'];
    $description = $_POST['description'];
    $totalMarks = $_POST['total_marks']; // Get the total marks from the form
    $dueDate = $_POST['due_date'];
    $facultyId = $_SESSION['user_id']; // Get the logged-in faculty ID

    // Check for existing assignments with the same title, description, and due date
    $checkQuery = "SELECT * FROM assignments WHERE class_id = ? AND title = ? AND description = ? AND due_date = ?";
    $checkStmt = $conn->prepare($checkQuery);
    $checkStmt->bind_param("isss", $classId, $title, $description, $dueDate);
    $checkStmt->execute();
    $checkResult = $checkStmt->get_result();

    if ($checkResult->num_rows > 0) {
        $_SESSION['error_message'] = "An assignment with the same title, description, and due date already exists for this class.";
    } else {
        // Insert assignment information into the database
        $stmt = $conn->prepare("INSERT INTO assignments (class_id, title, description, total_marks, due_date, faculty_id, created_at) VALUES (?, ?, ?, ?, ?, ?, NOW())");
        $stmt->bind_param("issisi", $classId, $title, $description, $totalMarks, $dueDate, $facultyId);
        
        if ($stmt->execute()) {
            // Fetch class details for logging
            $classDetails = $conn->query("SELECT c.class_name, d.department_name, yl.year_level 
                                           FROM classes c 
                                           LEFT JOIN departments d ON c.department_id = d.id 
                                           LEFT JOIN year_levels yl ON c.year_level_id = yl.id 
                                           WHERE c.id = $classId")->fetch_assoc();
            
            $className = $classDetails['class_name'];
            $departmentName = $classDetails['department_name'];
            $yearLevel = $classDetails['year_level'];

            $_SESSION['success_message'] = "Assignment created successfully for $className - $yearLevel ($departmentName).";
            logActivity($conn, $_SESSION['user_id'], 'Create Assignment', "Created assignment titled '$title' for class '$className' - '$yearLevel' ($departmentName).");
        } else {
            $_SESSION['error_message'] = "Database error: " . $stmt->error;
        }
        
        $stmt->close();
    }
    $checkStmt->close();
}

// Handle assignment update
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['update_assignment'])) {
    $assignmentId = $_POST['assignment_id'];
    $classId = $_POST['edit_class_id'];
    $title = $_POST['edit_title'];
    $description = $_POST['edit_description'];
    $totalMarks = $_POST['edit_total_marks']; // Get the total marks from the form
    $dueDate = $_POST['edit_due_date']; // Ensure this matches the input name

    // Check for existing assignments with the same title, description, and due date
    $checkQuery = "SELECT * FROM assignments WHERE class_id = ? AND title = ? AND description = ? AND due_date = ? AND id != ?";
    $checkStmt = $conn->prepare($checkQuery);
    $checkStmt->bind_param("isssi", $classId, $title, $description, $dueDate, $assignmentId);
    $checkStmt->execute();
    $checkResult = $checkStmt->get_result();

    if ($checkResult->num_rows > 0) {
        $_SESSION['error_message'] = "An assignment with the same title, description, and due date already exists for this class.";
    } else {
        // Fetch old assignment details
        $oldAssignment = $conn->query("SELECT class_id, title, description, due_date FROM assignments WHERE id = $assignmentId")->fetch_assoc();
        
        // Update assignment information in the database
        $stmt = $conn->prepare("UPDATE assignments SET class_id = ?, title = ?, description = ?, total_marks = ?, due_date = ? WHERE id = ?");
        $stmt->bind_param("issisi", $classId, $title, $description, $totalMarks, $dueDate, $assignmentId);
        
        if ($stmt->execute()) {
            // Fetch class details for logging
            $classDetails = $conn->query("SELECT c.class_name, d.department_name, yl.year_level 
                                           FROM classes c 
                                           LEFT JOIN departments d ON c.department_id = d.id 
                                           LEFT JOIN year_levels yl ON c.year_level_id = yl.id 
                                           WHERE c.id = $classId")->fetch_assoc();
            
            $className = $classDetails['class_name'];
            $departmentName = $classDetails['department_name'];
            $yearLevel = $classDetails['year_level'];

            // Log the changes
            logActivity($conn, $_SESSION['user_id'], 'Update Assignment', "Updated assignment ID $assignmentId from title '{$oldAssignment['title']}' to '$title' for class '$className' - '$yearLevel' ($departmentName). Old description: '{$oldAssignment['description']}', New description: '$description'. Old due date: '{$oldAssignment['due_date']}', New due date: '$dueDate'.");

            $_SESSION['success_message'] = "Assignment updated successfully for assignment ID $assignmentId from title '{$oldAssignment['title']}' to '$title' for class '$className' - '$yearLevel' ($departmentName). Old description: '{$oldAssignment['description']}', New description: '$description'. Old due date: '{$oldAssignment['due_date']}', New due date: '$dueDate'.";
        } else {
            $_SESSION['error_message'] = "Database error: " . $stmt->error;
        }
        
        $stmt->close();
    }
    $checkStmt->close();
}

// Handle assignment deletion
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['delete_assignment'])) {
    $assignmentId = $_POST['assignment_id'];

    // Fetch class details before deletion
    $classDetails = $conn->query("SELECT c.class_name, d.department_name, yl.year_level 
                                   FROM assignments a 
                                   LEFT JOIN classes c ON a.class_id = c.id 
                                   LEFT JOIN departments d ON c.department_id = d.id 
                                   LEFT JOIN year_levels yl ON c.year_level_id = yl.id 
                                   WHERE a.id = $assignmentId")->fetch_assoc();
    
    $className = $classDetails['class_name'];
    $departmentName = $classDetails['department_name'];
    $yearLevel = $classDetails['year_level'];

    // Delete assignment from the database
    $stmt = $conn->prepare("DELETE FROM assignments WHERE id = ?");
    $stmt->bind_param("i", $assignmentId);
    
    if ($stmt->execute()) {
        $_SESSION['success_message'] = "Assignment deleted successfully for $className - $yearLevel ($departmentName).";
        logActivity($conn, $_SESSION['user_id'], 'Delete Assignment', "Deleted assignment ID $assignmentId for class '$className' - '$yearLevel' ($departmentName).");
    } else {
        $_SESSION['error_message'] = "Database error: " . $stmt->error;
    }
    
    $stmt->close();
}

// Fetch assignments for the logged-in faculty
$query = "SELECT a.*, c.class_name, d.department_name, yl.year_level 
          FROM assignments a 
          LEFT JOIN classes c ON a.class_id = c.id 
          LEFT JOIN departments d ON c.department_id = d.id 
          LEFT JOIN year_levels yl ON c.year_level_id = yl.id 
          WHERE a.faculty_id = ? 
          ORDER BY a.due_date DESC";

$stmt = $conn->prepare($query);
$stmt->bind_param("i", $_SESSION['user_id']);
$stmt->execute();
$results = $stmt->get_result();

if (!$results) {
    die("Query failed: " . $conn->error);
}

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manage Assignments</title>
    <link rel="icon" href="../assets/images/logo.ico"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.bundle.min.js"></script>
    <style>
        body {
            background-color: #f4f6f9;
        }
        .container {
            margin-left: 250px;
            padding: 70px 30px;
            transition: margin-left 0.3s ease;
        }
        .sidebar {
            height: 100%;
            background-color: #6e8efb;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 65px !important;
            transition: width 0.3s ease;
        }

        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }

        .sidebar a:hover {
            background-color: #6e8efb;
        }

        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }

        .btn-primary:hover {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }
        .success {
            background-color: #d4edda; /* Light green */
        }
        .warning {
            background-color: #fff3cd; /* Light yellow */
        }
        .danger {
            background-color: #f8d7da; /* Light red */
        }
        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #6e8efb; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #f39c12; /* Hover effect for dropdown items */
        }
    </style>
</head>
<body>
    <!-- Header and Sidebar -->
    <?php include '../includes/faculty_header.php'; ?>
    <?php include '../includes/faculty_sidebar.php'; ?>
    <div class="container">
        <h1>Manage Assignments</h1>

        <?php
        if (isset($_SESSION['success_message'])) {
            echo "<div class='alert alert-success'>{$_SESSION['success_message']}</div>";
            unset($_SESSION['success_message']);
        }
        if (isset($_SESSION['error_message'])) {
            echo "<div class='alert alert-danger'>{$_SESSION['error_message']}</div>";
            unset($_SESSION['error_message']);
        }
        ?>

        <!-- Button to Open the Add Assignment Modal -->
        <button type="button" class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#addAssignmentModal">
            <i class="fas fa-plus"></i> Create New Assignment
        </button>

        <!-- Add Assignment Modal -->
        <div class="modal fade" id="addAssignmentModal" tabindex="-1" aria-labelledby="addAssignmentModalLabel" aria-hidden="true">
            <div class="modal-dialog">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title" id="addAssignmentModalLabel">Create New Assignment</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                    </div>
                    <div class="modal-body">
                        <form action="uploaded_assignments.php" method="post">
                            <div class="mb-3">
                                <label for="class_id" class="form-label">Select Class:</label>
                                <select name="class_id" id="class_id" class="form-select" required>
                                    <?php while ($row = $classResult->fetch_assoc()): ?>
                                        <option value="<?= $row['id']; ?>">
                                            <?= htmlspecialchars($row['class_name'] . ' - ' . $row['year_level'] . ' (' . $row['department_name'] . ')'); ?>
                                        </option>
                                    <?php endwhile; ?>
                                </select>
                            </div>
                            <div class="mb-3">
                                <label for="title" class="form-label">Assignment Title:</label>
                                <input type="text" name="title" id="title" class="form-control" required>
                            </div>
                            <div class="mb-3">
                                <label for="description" class="form-label">Description:</label>
                                <textarea name="description" id="description" class="form-control" rows="4" required></textarea>
                            </div>
                            <div class="mb-3">
                                <label for="total_marks" class="form-label">Total Marks:</label>
                                <input type="number" name="total_marks" id="total_marks" class="form-control" required>
                            </div>
                            <div class="mb-3">
                                <label for="due_date" class="form-label">Due Date:</label>
                                <input type="date" name="due_date" id="due_date" class="form-control" required>
                            </div>
                            <button type="submit" name="create_assignment" class="btn btn-primary">Create Assignment</button>
                        </form>
                    </div>
                </div>
            </div>
        </div>

        <h2>All Assignments</h2>
        <table class="table">
            <thead>
                <tr>
                    <th>S.No.</th>
                    <th>Title</th>
                    <th>Description</th>
                    <th>Class</th>
                    <th>Total Marks</th>
                    <th>Due Date</th>
                    <th>Created At</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
            <?php if ($results->num_rows > 0): ?>
                <?php $serialNumber = 1; // Initialize serial number ?>
                <?php $currentDate = new DateTime(); // Current date ?>
                <?php while ($assignment = $results->fetch_assoc()): ?>
                    <?php
                    $dueDate = new DateTime($assignment['due_date']);
                    $interval = $currentDate->diff($dueDate);
                    
                    // Determine the class based on the due date
                    if ($dueDate < $currentDate) {
                        $class = 'danger'; // Overdue
                    } elseif ($interval->days < 1) {
                        $class = 'danger'; // Due today
                    } elseif ($interval->days <= 3) {
                        $class = 'warning'; // Due in 3 days
                    } else {
                        $class = 'success'; // More than 3 days away
                    }
                    ?>
                    <tr class="<?= $class; ?>">
                        <td><?= $serialNumber++; ?></td> <!-- Display serial number -->
                        <td><?= htmlspecialchars($assignment['title']); ?></td>
                        <td><?= htmlspecialchars($assignment['description']); ?></td>
                        <td><?= htmlspecialchars($assignment['class_name'] . ' - ' . $assignment['year_level'] . ' (' . $assignment['department_name'] . ')'); ?></td>
                        <td><?= htmlspecialchars($assignment['total_marks']); ?></td>
                        <td><?= htmlspecialchars($assignment['due_date']); ?></td>
                        <td><?= htmlspecialchars($assignment['created_at']); ?></td>
                        <td>
                            <button class="btn btn-warning" data-bs-toggle="modal" data-bs-target="#editModal<?= $assignment['id']; ?>">
                                <i class="fas fa-edit"></i> Edit
                            </button>
                            <button class="btn btn-danger" data-bs-toggle="modal" data-bs-target="#deleteModal<?= $assignment['id']; ?>">
                                <i class="fas fa-trash"></i> Delete
                            </button>
                            <a href="view_submissions.php?assignment_id=<?= $assignment['id']; ?>" class="btn btn-info">
                                <i class="fas fa-eye"></i> View Submissions
                            </a>
                        </td>
                    </tr>

                    <!-- Edit Modal -->
                    <div class="modal fade" id="editModal<?= $assignment['id']; ?>" tabindex="-1" aria-labelledby="editModalLabel" aria-hidden="true">
                        <div class="modal-dialog">
                            <div class="modal-content">
                                <div class="modal-header">
                                    <h5 class="modal-title" id="editModalLabel">Edit Assignment</h5>
                                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                </div>
                                <div class="modal-body">
                                    <form action="uploaded_assignments.php" method="post">
                                        <input type="hidden" name="assignment_id" value="<?= $assignment['id']; ?>">
                                        <div class="mb-3">
                                            <label for="edit_class_id" class="form-label">Select Class:</label>
                                            <select name="edit_class_id" id="edit_class_id" class="form-select" required>
                                                <?php
                                                // Reset the class result pointer to the beginning
                                                $classResult->data_seek(0);
                                                while ($row = $classResult->fetch_assoc()): ?>
                                                    <option value="<?= $row['id']; ?>" <?= $row['id'] == $assignment['class_id'] ? 'selected' : ''; ?>>
                                                        <?= htmlspecialchars($row['class_name'] . ' - ' . $row['year_level'] . ' (' . $row['department_name'] . ')'); ?>
                                                    </option>
                                                <?php endwhile; ?>
                                            </select>
                                        </div>
                                        <div class="mb-3">
                                            <label for="edit_title" class="form-label">Assignment Title:</label>
                                            <input type="text" name="edit_title" id="edit_title" class="form-control" value="<?= htmlspecialchars($assignment['title']); ?>" required>
                                        </div>
                                        <div class="mb-3">
                                            <label for="edit_description" class="form-label">Description:</label>
                                            <textarea name="edit_description" id="edit_description" class="form-control" rows="4" required><?= htmlspecialchars($assignment['description']); ?></textarea>
                                        </div>
                                        <div class="mb-3">
                                            <label for="edit_total_marks" class="form-label">Total Marks:</label>
                                            <input type="number" name="edit_total_marks" id="edit_total_marks" class="form-control" value="<?= htmlspecialchars($assignment['total_marks']); ?>" required>
                                        </div>
                                        <div class="mb-3">
                                            <label for="edit_due_date" class="form-label">Due Date:</label>
                                            <input type="date" name="edit_due_date" id="edit_due_date" class="form-control" value="<?= htmlspecialchars($assignment['due_date']); ?>" required>
                                        </div>
                                        <button type="submit" name="update_assignment" class="btn btn-primary">Update Assignment</button>
                                    </form>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Delete Modal -->
                    <div class="modal fade" id="deleteModal<?= $assignment['id']; ?>" tabindex="-1" aria-labelledby="deleteModalLabel" aria-hidden="true">
                        <div class="modal-dialog">
                            <div class="modal-content">
                                <div class="modal-header">
                                    <h5 class="modal-title" id="deleteModalLabel">Delete Assignment</h5>
                                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                </div>
                                <div class="modal-body">
                                    Are you sure you want to delete this assignment?
                                </div>
                                <div class="modal-footer">
                                    <form action="uploaded_assignments.php" method="post">
                                        <input type="hidden" name="assignment_id" value="<?= $assignment['id']; ?>">
                                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                                        <button type="submit" name="delete_assignment" class="btn btn-danger">Delete</button>
                                    </form>
                                </div>
                            </div>
                        </div>
                    </div>

                <?php endwhile; ?>
            <?php else: ?>
                <tr>
                    <td colspan="7" class="text-center">No assignments created yet.</td>
                </tr>
            <?php endif; ?>
            </tbody>
        </table>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

<?php
// Close the database connection
$conn->close();
?>