<?php
session_start();
// Check if the user is logged in and has the role of 'faculty'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'faculty') {
    header("Location: ../login.php");
    exit();
}

// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

include '../includes/dbcon.php'; // Include database connection

// Fetch the assignment ID from the URL
$assignmentId = $_GET['assignment_id'] ?? null;
$assignmentTitle = 'N/A'; // Default value for assignment title
$assignmentDescription = 'N/A'; // Default value for assignment description
$dueDate = 'N/A'; // Default value for due date
$facultyFirstName = 'N/A'; // Default value for faculty first name
$facultyLastName = 'N/A'; // Default value for faculty last name
$className = 'N/A'; // Default value for class name
$departmentName = 'N/A'; // Default value for department name
$yearLevel = 'N/A'; // Default value for year level

// Pagination variables
$limit = 10; // Number of submissions per page
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$offset = ($page - 1) * $limit;

if ($assignmentId) {
    // First, check if the assignment exists
    $assignmentQuery = "SELECT a.title, a.description, a.class_id, a.due_date, a.total_marks, u.first_name, u.last_name, 
                           c.class_name, d.department_name, yl.year_level 
                    FROM assignments a 
                    LEFT JOIN users u ON a.faculty_id = u.id 
                    LEFT JOIN classes c ON a.class_id = c.id 
                    LEFT JOIN departments d ON c.department_id = d.id 
                    LEFT JOIN year_levels yl ON c.year_level_id = yl.id 
                    WHERE a.id = ?";
    $stmt = $conn->prepare($assignmentQuery);
    $stmt->bind_param("i", $assignmentId);
    $stmt->execute();
    $assignmentResult = $stmt->get_result();

    if ($assignmentResult->num_rows > 0) {
        // Fetch the assignment details
        $assignment = $assignmentResult->fetch_assoc();
        $assignmentTitle = htmlspecialchars($assignment['title']);
        $assignmentDescription = htmlspecialchars($assignment['description']);
        $dueDate = htmlspecialchars($assignment['due_date']);
        $totalMarks = htmlspecialchars($assignment['total_marks']); // Fetch total marks
        $facultyFirstName = htmlspecialchars($assignment['first_name']);
        $facultyLastName = htmlspecialchars($assignment['last_name']);
        $className = htmlspecialchars($assignment['class_name']);
        $departmentName = htmlspecialchars($assignment['department_name']);
        $yearLevel = htmlspecialchars($assignment['year_level']);
        
        // Now fetch submissions for the assignment
        $submissionQuery = "SELECT s.id AS submission_id, s.file_path, s.submitted_at, 
                                   g.grade, g.feedback, u.first_name AS student_first_name, 
                                   u.last_name AS student_last_name 
                            FROM submissions s 
                            LEFT JOIN grades g ON s.id = g.submission_id 
                            LEFT JOIN users u ON s.student_id = u.id 
                            WHERE s.assignment_id = ? 
                            LIMIT ? OFFSET ?";
        
        $stmt = $conn->prepare($submissionQuery);
        $stmt->bind_param("iii", $assignmentId, $limit, $offset);
        $stmt->execute();
        $results = $stmt->get_result();
    } else {
        // Assignment not found
        echo '<div class="alert alert-danger">Assignment not found.</div>';
        exit();
    }
} else {
    echo '<div class="alert alert-danger">No assignment selected.</div>';
    exit();
}

// Handle grading submission
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['grade_submission'])) {
    $submissionId = $_POST['submission_id'];
    $grade = $_POST['grade'];
    $feedback = trim($_POST['feedback']); // Trim whitespace

    // Validate inputs
    if (empty($submissionId) || !is_numeric($submissionId)) {
        $_SESSION['error_message'] = "Invalid submission ID.";
    } elseif (!is_numeric($grade) || $grade < 0 || $grade > $assignment['total_marks']) {
        $_SESSION['error_message'] = "Grade must be a number between 0 and " . $assignment['total_marks'] . ".";
    } elseif (empty($feedback)) {
        $_SESSION['error_message'] = "Feedback cannot be empty.";
    } else {
        // Check if a grade already exists for the submission
        $checkQuery = "SELECT * FROM grades WHERE submission_id = ?";
        $stmt = $conn->prepare($checkQuery);
        $stmt->bind_param("i", $submissionId);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows > 0) {
            // Update existing grade and feedback
            $stmt = $conn->prepare("UPDATE grades SET grade = ?, feedback = ? WHERE submission_id = ?");
            $stmt->bind_param("isi", $grade, $feedback, $submissionId);
        } else {
            // Create new grade entry
            $stmt = $conn->prepare("INSERT INTO grades (submission_id, grade, feedback) VALUES (?, ?, ?)");
            $stmt->bind_param("iis", $submissionId, $grade, $feedback);
        }

        if ($stmt->execute()) {
            $_SESSION['success_message'] = "Grade updated successfully.";
        } else {
            $_SESSION['error_message'] = "Database error: " . $stmt->error;
        }
        
        $stmt->close();
    }
}

// Fetch total submissions for pagination
$totalQuery = "SELECT COUNT(*) as total FROM submissions WHERE assignment_id = ?";
$totalStmt = $conn->prepare($totalQuery);
$totalStmt->bind_param("i", $assignmentId);
$totalStmt->execute();
$totalResult = $totalStmt->get_result();
$totalRow = $totalResult->fetch_assoc();
$totalSubmissions = $totalRow['total'];
$totalPages = ceil($totalSubmissions / $limit);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>View Submissions</title>
    <link rel="icon" href="../assets/images/logo.ico"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f4f6f9;
        }
        .container {
            margin-left: 250px;
            padding: 80px 30px;
            transition: margin-left 0.3s ease;
        }
        .sidebar {
            height: 100%;
            background-color: #6e8efb;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 65px !important;
            transition: width 0.3s ease;
        }

        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }

        .sidebar a:hover {
            background-color: #6e8efb;
        }

        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }

        .btn-primary:hover {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }
        .success {
            background-color: #d4edda; /* Light green */
        }
        .warning {
            background-color: #fff3cd; /* Light yellow */
        }
        .danger {
            background-color: #f8d7da; /* Light red */
        }
        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #6e8efb; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #f39c12; /* Hover effect for dropdown items */
        }
    </style>
</head>
<body>
    <!-- Header and Sidebar -->
    <?php include '../includes/faculty_header.php'; ?>
    <?php include '../includes/faculty_sidebar.php'; ?>
    <div class="container">
        <h1>Submissions for Assignment: <?= $assignmentTitle; ?></h1>
        <p><strong>Description:</strong> <?= $assignmentDescription; ?></p>
        <p><strong>Class:</strong> <?= $className . " (" . $departmentName . " - " . $yearLevel . ")"; ?></p>
        <p><strong>Due Date:</strong> <?= $dueDate; ?></p>
        <p><strong>Created by:</strong> <?= $facultyFirstName . ' ' . $facultyLastName; ?></p>

        <?php
        // Display any success or error messages
        if (isset($_SESSION['success_message'])) {
            echo '<div class="alert alert-success">' . $_SESSION['success_message'] . '</div>';
            unset($_SESSION['success_message']); // Clear the message after displaying
        }

        if (isset($_SESSION['error_message'])) {
            echo '<div class="alert alert-danger">' . $_SESSION['error_message'] . '</div>';
            unset($_SESSION['error_message']); // Clear the message after displaying
        }
        ?>

        <table class="table">
            <thead>
                <tr>
                    <th>S.No.</th>
                    <th>Student Name</th>
                    <th>Class</th>
                    <th>File Path</th>
                    <th>Submitted At</th>
                    <th>Obtained Marks</th>
                    <th>Total Marks</th>
                    <th>Feedback</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
            <?php if (isset($results) && $results->num_rows > 0): ?>
                <?php $serialNumber = 1; ?>
                <?php while ($submission = $results->fetch_assoc()): ?>
                    <tr>
                        <td><?= $serialNumber++; ?></td>
                        <td><?= htmlspecialchars($submission['student_first_name'] . ' ' . $submission['student_last_name']); ?></td>
                        <td><?= htmlspecialchars($className . " (" . $departmentName . " - " . $yearLevel . ")"); ?></td>
                        <td>
                            <a href="<?= htmlspecialchars($submission['file_path']); ?>" target="_blank" class="btn btn-primary">
                                <i class="fas fa-eye"></i> View File
                            </a>
                        </td>
                        <td><?= htmlspecialchars($submission['submitted_at']); ?></td>
                        <td>
                            <form action="view_submissions.php?assignment_id=<?= $assignmentId; ?>" method="post">
                                <input type="hidden" name="submission_id" value="<?= $submission['submission_id']; ?>">
                                <input type="number" name="grade" value="<?= htmlspecialchars($submission['grade'] ?? ''); ?>" required min="0" max="<?= $totalMarks; ?>">
                        </td>
                        <td>
                            <?= $totalMarks; ?>
                        </td>
                        <td>
                            <textarea name="feedback" rows="2" required><?= htmlspecialchars($submission['feedback'] ?? ''); ?></textarea>
                        </td>
                        <td>
                            <button type="submit" name="grade_submission" class="btn btn-success">
                                <i class="fas fa-check"></i> Grade
                            </button>
                            </form> <!-- Close the form here -->
                        </td>
                    </tr>
                <?php endwhile; ?>
            <?php else: ?>
                <tr>
                    <td colspan="9" class="text-center">No submissions found for this assignment.</td>
                </tr>
            <?php endif; ?>
            </tbody>
        </table>

        <nav aria-label="Page navigation">
            <ul class="pagination">
                <?php for ($i = 1; $i <= $totalPages; $i++): ?>
                    <li class="page-item<?= ($i == $page) ? ' active' : '' ?>">
                        <a class="page-link" href="?assignment_id=<?= $assignmentId; ?>&page=<?= $i; ?>"><?= $i; ?></a>
                    </li>
                <?php endfor; ?>
            </ul>
        </nav>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
</body>
</html>

<?php
// Close the database connection
$conn->close();
?>