<?php
session_start();
// Check if the user is logged in and has the role of 'student'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'student') {
    header("Location: ../login.php");
    exit();
}

include '../includes/dbcon.php'; // Include database connection

// Fetch assigned classes for the logged-in student
$studentId = $_SESSION['user_id'];
$query = "SELECT c.id, c.class_name, yl.year_level, d.department_name 
          FROM student_classes sc 
          JOIN classes c ON sc.class_id = c.id 
          LEFT JOIN year_levels yl ON c.year_level_id = yl.id 
          LEFT JOIN departments d ON c.department_id = d.id 
          WHERE sc.student_id = ?";

$stmt = $conn->prepare($query);
$stmt->bind_param("i", $studentId);
$stmt->execute();
$assignedClassesResult = $stmt->get_result();

$assignedClasses = [];
while ($row = $assignedClassesResult->fetch_assoc()) {
    $assignedClasses[] = $row;
}

// Fetch materials uploaded for the assigned classes
$materialsQuery = "SELECT m.*, u.username, c.class_name, yl.year_level, d.department_name 
                   FROM materials m 
                   LEFT JOIN users u ON m.faculty_id = u.id 
                   LEFT JOIN classes c ON m.class_id = c.id 
                   LEFT JOIN year_levels yl ON c.year_level_id = yl.id 
                   LEFT JOIN departments d ON c.department_id = d.id 
                   WHERE m.class_id IN (SELECT class_id FROM student_classes WHERE student_id = ?) 
                   ORDER BY m.uploaded_at DESC";

$materialsStmt = $conn->prepare($materialsQuery);
$materialsStmt->bind_param("i", $studentId);
$materialsStmt->execute();
$materialsResults = $materialsStmt->get_result();

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Downloadable Materials</title>
    <link rel="icon" href="../assets/images/logo.ico"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f4f6f9;
        }
        .container {
            margin-left: 250px;
            padding: 80px 30px;
            transition: margin-left 0.3s ease;
        }
        .sidebar {
            height: 100%;
            background-color: #f39c12;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 65px !important;
            transition: width 0.3s ease;
        }
        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }
        .sidebar a:hover {
            background-color: #6e8efb;
        }
        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #f39c12; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #6e8efb; /* Hover effect for dropdown items */
        }
    </style>
</head>
<body>
    <?php include '../includes/student_header.php'; ?>
    <?php include '../includes/student_sidebar.php'; ?>

    <div class="container">
        <h1>Your Downloadable Materials</h1>
        <?php if (isset($_SESSION['error_message'])): ?>
            <div class="alert alert-danger">
                <?= htmlspecialchars($_SESSION['error_message']); ?>
                <?php unset($_SESSION['error_message']); ?>
            </div>
        <?php endif; ?>
        <?php if (isset($_SESSION['success_message'])): ?>
            <div class="alert alert-success">
                <?= htmlspecialchars($_SESSION['success_message']); ?>
                <?php unset($_SESSION['success_message']); ?>
            </div>
        <?php endif; ?>

        <h2>Assigned Classes</h2>
        <ul>
            <?php foreach ($assignedClasses as $class): ?>
                <li><?= htmlspecialchars($class['class_name'] . ' - ' . $class['year_level'] . ' (' . $class['department_name'] . ')'); ?></li>
            <?php endforeach; ?>
        </ul>

        <h2>Materials</h2>
        <table class="table table-striped">
            <thead>
                <tr>
                    <th>S.No.</th>
                    <th>File Name</th>
                    <th>Uploaded By</th>
                    <th>Class</th>
                    <th>Year Level</th>
                    <th>Department</th>
                    <th>Uploaded At</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php if ($materialsResults->num_rows > 0): ?>
                    <?php $serialNumber = 1; ?>
                    <?php while ($material = $materialsResults->fetch_assoc()): ?>
                        <tr>
                            <td><?= $serialNumber++; ?></td>
                            <td><?= htmlspecialchars(basename($material['file_path'])); ?></td>
                            <td><?= htmlspecialchars($material['username']); ?></td>
                            <td><?= htmlspecialchars($material['class_name']); ?></td>
                            <td><?= htmlspecialchars($material['year_level']); ?></td>
                            <td><?= htmlspecialchars($material['department_name']); ?></td>
                            <td><?= htmlspecialchars($material['uploaded_at']); ?></td>
                            <td>
                                <a href="download.php?id=<?= $material['id']; ?>" class="btn btn-success btn-sm" title="Download">
                                    <i class="fas fa-download"></i> Download
                                </a>
                            </td>
                        </tr>
                    <?php endwhile; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="8" class="text-center">No materials available for your classes.</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.bundle.min .js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

<?php
$materialsStmt->close();
$stmt->close();
$conn->close();
?>