<?php
session_start();

// Check if user is a student
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'student') {
    header("Location: ../login.php");
    exit();
}

include '../includes/dbcon.php';

// Get the quiz ID
if (!isset($_GET['quiz_id'])) {
    die("Quiz ID is required.");
}

$quiz_id = intval($_GET['quiz_id']);
$student_id = $_SESSION['user_id'];

// Check if the quiz was already submitted
$check_submission_stmt = $conn->prepare("SELECT score FROM quiz_results WHERE student_id = ? AND quiz_id = ?");
$check_submission_stmt->bind_param("ii", $student_id, $quiz_id);
$check_submission_stmt->execute();
$submission_result = $check_submission_stmt->get_result();

if ($submission_result->num_rows > 0) {
    header("Location: leaderboard.php?quiz_id=" . $quiz_id);
    exit();
}

// Fetch quiz details
$quiz_stmt = $conn->prepare("SELECT * FROM quizzes WHERE id = ?");
$quiz_stmt->bind_param("i", $quiz_id);
$quiz_stmt->execute();
$quiz_result = $quiz_stmt->get_result();

if ($quiz_result->num_rows === 0) {
    die("Quiz not found.");
}

$quiz = $quiz_result->fetch_assoc();
$quiz_stmt->close();

// Fetch questions and options, including question_type
$questions_stmt = $conn->prepare("SELECT q.id AS question_id, q.question_text, q.question_type, o.option_id, o.option_text 
                                  FROM quiz_questions q 
                                  LEFT JOIN quiz_options o ON q.id = o.question_id 
                                  WHERE q.quiz_id = ?");
$questions_stmt->bind_param("i", $quiz_id);
$questions_stmt->execute();
$questions_result = $questions_stmt->get_result();

$questions = [];
while ($row = $questions_result->fetch_assoc()) {
    $questions[$row['question_id']]['question_text'] = $row['question_text'];
    $questions[$row['question_id']]['question_type'] = $row['question_type']; // Store question type
    if ($row['option_id']) {
        $questions[$row['question_id']]['options'][] = [
            'id' => $row['option_id'],
            'text' => $row['option_text']
        ];
    }
}
$questions_stmt->close();

// Initialize session variables
if (!isset($_SESSION['questions'])) {
    $_SESSION['questions'] = $questions;
    $_SESSION['current_question'] = 0;
    $_SESSION['score'] = 0;
    $_SESSION['total_questions'] = count($questions);
    $_SESSION['timer'] = 60; // Set timer for 1 minute
    $_SESSION['tab_switch_count'] = 0;
}

// Handle quiz submission
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $current_question_id = array_keys($_SESSION['questions'])[$_SESSION['current_question']];
    $selected_options = $_POST['answers'][$current_question_id] ?? [];

    // Ensure selected_options is always an array
    if (!is_array($selected_options)) {
        $selected_options = [$selected_options];
    }

    // Fetch correct answers
    $correct_stmt = $conn->prepare("SELECT option_id FROM quiz_options WHERE question_id = ? AND is_correct = 1");
    $correct_stmt->bind_param("i", $current_question_id);
    $correct_stmt->execute();
    $correct_result = $correct_stmt->get_result();

    $correct_options = [];
    while ($correct_row = $correct_result->fetch_assoc()) {
        $correct_options[] = $correct_row['option_id'];
    }
    $correct_stmt->close();

    // Check answer correctness
    $is_correct = (array_diff($selected_options, $correct_options) === [] && count($selected_options) === count($correct_options));
    if ($is_correct) {
        $_SESSION['score']++;
    }

    $_SESSION['current_question']++;

    // If quiz completed, save results
    if ($_SESSION['current_question'] >= $_SESSION['total_questions']) {
        $incorrect_answers = $_SESSION['total_questions'] - $_SESSION['score'];
        $insert_result_stmt = $conn->prepare("INSERT INTO quiz_results (student_id, class_id, quiz_id, score, total_questions, correct_answers, incorrect_answers, quiz_submitted_date) VALUES (?, ?, ?, ?, ?, ?, ?, NOW())");
        $insert_result_stmt->bind_param("iiiiiii", $_SESSION['user_id'], $quiz['class_id'], $quiz_id, $_SESSION['score'], $_SESSION['total_questions'], $_SESSION['score'], $incorrect_answers);
        $insert_result_stmt->execute();
        $insert_result_stmt->close();

        // Clear session variables
        unset($_SESSION['questions'], $_SESSION['current_question'], $_SESSION['score'], $_SESSION['total_questions'], $_SESSION['timer'], $_SESSION['tab_switch_count']);

        header("Location: leaderboard.php?quiz_id=" . $quiz_id);
        exit();
    }
}

// Get current question
$current_question = array_keys($_SESSION['questions'])[$_SESSION['current_question']];
$question_type = $_SESSION['questions'][$current_question]['question_type'];
$input_type = ($question_type === 'multiple_choice') ? 'radio' : 'checkbox';
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo htmlspecialchars($quiz['title']); ?></title>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css">
    <style>
        .container {
            padding: 80px 30px;
        }
        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #f39c12; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #6e8efb; /* Hover effect for dropdown items */
        }
    </style>
    <script>
        let timeLeft = <?php echo $_SESSION['timer']; ?>;
        let tabSwitchCount = 0;

        function updateTimer() {
            const minutes = Math.floor(timeLeft / 60);
            const seconds = timeLeft % 60;
            document.getElementById('timer').textContent = `Time Left: ${minutes}:${seconds < 10 ? '0' : ''}${seconds}`;
            if (timeLeft <= 0) {
                document.getElementById('quizForm').submit();
            }
            timeLeft--;
        }

        // Disable back and refresh
        window.history.pushState(null, null, window.location.href);
        window.addEventListener('popstate', function(event) {
            window.history.pushState(null, null, window.location.href);
            alert("You cannot go back during the quiz!");
        });

        window.addEventListener('beforeunload', function(event) {
            event.preventDefault();
            event.returnValue = "You have an ongoing quiz. Leaving this page will submit your test.";
        });

        // Prevent tab switching
        document.addEventListener("visibilitychange", function() {
            if (document.hidden) {
                tabSwitchCount++;
                alert("Warning! Do not switch tabs.");
                if (tabSwitchCount >= 3) {
                    alert("You switched tabs too many times. Submitting quiz.");
                    document.getElementById('quizForm').submit();
                }
            }
        });
        
        // Add confirmation dialog for form submission
        document.getElementById('quizForm').addEventListener('submit', function(event) {
            event.preventDefault(); // Prevent the default form submission

            // Show confirmation dialog
            const confirmation = confirm("Are you sure you want to submit this answer? Your quiz progress will move to the next question.");
            if (confirmation) {
                this.submit(); // Submit the form if the user confirms
            }
        });

        window.onload = function() {
            setInterval(updateTimer, 1000);
        };
    </script>
</head>
<body>
    <?php include('../includes/student_header.php'); ?>

    <div class="container">
        <h1><?php echo htmlspecialchars($quiz['title']); ?></h1>
        <div id="timer" class="alert alert-warning">Time Left: 1:00</div>
        <form method="POST" action="" id="quizForm">
            <div class="card p-3">
                <h5><?php echo htmlspecialchars($_SESSION['questions'][$current_question]['question_text']); ?></h5>
                <?php foreach ($_SESSION['questions'][$current_question]['options'] as $option): ?>
                    <div class="form-check">
                        <input class="form-check-input" type="<?php echo $input_type; ?>" 
                               name="answers[<?php echo $current_question; ?>]<?php echo ($input_type === 'radio') ? '' : '[]'; ?>" 
                               value="<?php echo $option['id']; ?>">
                        <label class="form-check-label"><?php echo htmlspecialchars($option['text']); ?></label>
                    </div>
                <?php endforeach; ?>
            </div>
            <button type="submit" class="btn btn-primary mt-3">Next Question</button>
            <p><b>Note:</b> After clicking Next question, Leave site pop up will be shown in that click leave to submit the answer.</p>
        </form>
    </div>
</body>
</html>
