<?php
session_start();
include '../includes/dbcon.php'; // Include your database connection file

// Check if the user is logged in
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php"); // Redirect to login if not logged in
    exit();
}

// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

$user_id = $_SESSION['user_id'];

// Initialize variables for selected month, year, and class
$selected_month = isset($_POST['month']) ? $_POST['month'] : date('m');
$selected_year = isset($_POST['year']) ? $_POST['year'] : date('Y');
$selected_class_id = isset($_POST['class_id']) ? $_POST['class_id'] : null;

// Fetch classes for the logged-in student
$class_query = "SELECT c.id, c.class_name, d.department_name, yl.year_level
                FROM student_classes sc
                JOIN classes c ON sc.class_id = c.id
                JOIN departments d ON c.department_id = d.id
                JOIN year_levels yl ON c.year_level_id = yl.id
                WHERE sc.student_id = ?";
$stmt = $conn->prepare($class_query);
$stmt->bind_param("i", $user_id);
$stmt->execute();
$class_results = $stmt->get_result();

// Initialize attendance records and summary
$attendance_records = [];
$attendance_summary = [];

// Fetch attendance records for the selected class based on selected month and year
if ($selected_class_id) {
    // Fetch attendance records for the selected class
    $attendance_query = "SELECT a.date, a.status 
                         FROM attendance a
                         WHERE a.student_id = ? AND a.class_id = ? 
                         AND MONTH(a.date) = ? AND YEAR(a.date) = ?";
    $attendance_stmt = $conn->prepare($attendance_query);
    $attendance_stmt->bind_param("iiii", $user_id, $selected_class_id, $selected_month, $selected_year);
    $attendance_stmt->execute();
    $attendance_result = $attendance_stmt->get_result();

    // Store attendance records and calculate monthly summary
    while ($attendance_row = $attendance_result->fetch_assoc()) {
        $attendance_records[] = [
            'date' => $attendance_row['date'],
            'status' => $attendance_row['status']
        ];

        // Calculate monthly attendance summary
        $month = date('Y-m', strtotime($attendance_row['date']));
        if (!isset($attendance_summary[$month])) {
            $attendance_summary[$month] = [
                'total_days' => 0,
                'present' => 0,
                'absent' => 0,
                'on_duty' => 0,
                'holiday' => 0
            ];
        }

        // Count attendance status
        switch ($attendance_row['status']) {
            case 'present':
                $attendance_summary[$month]['present']++;
                break;
            case 'absent':
                $attendance_summary[$month]['absent']++;
                break;
            case 'on-duty':
                $attendance_summary[$month]['on_duty']++;
                break;
            case 'holiday':
                $attendance_summary[$month]['holiday']++;
                break;
        }
    }
    $attendance_stmt->close();
}

// Calculate total days in the selected month
$first_day = new DateTime("first day of $selected_year-$selected_month");
$last_day = new DateTime("last day of $selected_year-$selected_month");
$last_day->modify('+1 day'); // To include the last day in the loop

$total_days = 0;
$holidays = 0; // Initialize holidays count

// Count total days and holidays based on attendance records
for ($date = $first_day; $date < $last_day; $date->modify('+1 day')) {
    $total_days++;
}

// Count holidays from attendance summary
if (isset($attendance_summary["$selected_year-$selected_month"])) {
    $holidays = $attendance_summary["$selected_year-$selected_month"]['holiday'];
}

// Calculate working days (total days - holidays)
$working_days = $total_days - $holidays;

// Calculate attendance percentage for the selected month
$attendance_percentage = 0;
if (isset($attendance_summary["$selected_year-$selected_month"])) {
    $present_days = $attendance_summary["$selected_year-$selected_month"]['present'];
    $on_duty_days = $attendance_summary["$selected_year-$selected_month"]['on_duty']; // Get on-duty days
    $total_present_days = $present_days + $on_duty_days; // Include on-duty days in present days
    $attendance_percentage = ($working_days > 0) ? ($total_present_days / $working_days) * 100 : 0;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>My Attendance</title>
    <link rel="icon" href="../assets/images/logo.ico" type="image/x-icon">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <style>
        body {
            background-color: #f4f6f9;
        }
        .container {
            margin-left: 250px; /* Default margin for larger screens */
            padding: 80px 50px;
        }
        @media (max-width: 768px) {
            .container {
                margin-left: 0; /* Remove margin for mobile screens */
                padding: 80px 30px;
            }
        }
        .card {
            margin-bottom: 20px;
            z-index: 1; /* Lower z-index for cards */
            position: relative; /* Required for z-index to work */
            border-radius: 10px; /* Rounded corners */
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1); /* Box shadow */
            transition: transform 0.2s; /* Smooth transition */
        }
        .card:hover {
            transform: translateY(-5px); /* Lift effect on hover */
        }
        .table th, .table td {
            vertical-align: middle;
        }
        .table-striped tbody tr:nth-of-type(odd) {
            background-color: #f9f9f9;
        }
        .table-striped tbody tr:hover {
            background-color: #e9ecef;
        }
        .card-header {
            background-color: #6e8efb; /* Primary color */
            color: white;
            border-top-left-radius: 10px;
            border-top-right-radius: 10px;
            z-index: 2; /* Higher z-index for card header */
            position: relative; /* Required for z-index to work */
        }
        .card-header i {
            margin-right: 8px; /* Space between icon and text */
        }
        .alert {
            margin-bottom: 20px;
            margin: 0 150px;
        }
        .sidebar {
            height: 100%;
            background-color: #f39c12;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 75px !important;
            transition: width 0.3s ease;
        }
        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }
        .sidebar a:hover {
            background-color: #6e8efb;
        }
        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }
        .btn-primary:hover {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }
        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #f39c12; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #6e8efb; /* Hover effect for dropdown items */
        }
    </style>
</head>
<body>
    <!-- Include Header -->
    <?php include('../includes/student_header.php'); ?>
    <?php include('../includes/student_sidebar.php'); ?>

    <div class="container">
        <h1 class="mb-4">My Attendance</h1>

        <!-- Month, Year, and Class Selection Form -->
        <div class="card">
            <div class="card-body">
                <form method="POST" class="mb-4">
                    <div class="row">
                        <div class="col-md-4 mb-3">
                            <label for="month" class="form-label">Select Month</label>
                            <select class="form-select" id="month" name="month" required>
                                <?php for ($m = 1; $m <= 12; $m++): ?>
                                    <option value="<?= str_pad($m, 2, '0', STR_PAD_LEFT); ?>" <?= ($selected_month == str_pad($m, 2, '0', STR_PAD_LEFT)) ? 'selected' : ''; ?>>
                                        <?= date('F', mktime(0, 0, 0, $m, 1)); ?>
                                    </option>
                                <?php endfor; ?>
                            </select>
                        </div>
                        <div class="col-md-4 mb-3">
                            <label for="year" class="form-label">Select Year</label>
                            <select class="form-select" id="year" name="year" required>
                                <?php for ($y = date('Y') - 5; $y <= date('Y'); $y++): ?>
                                    <option value="<?= $y; ?>" <?= ($selected_year == $y) ? 'selected' : ''; ?>><?= $y; ?></option>
                                <?php endfor; ?>
                            </select>
                        </div>
                        <div class="col-md-4 mb-3">
                            <label for="class_id" class="form-label">Select Class</label>
                            <select class="form-select" id="class_id" name="class_id" required>
                                <option value="">-- Select Class --</option>
                                <?php while ($class_row = $class_results->fetch_assoc()): ?>
                                    <option value="<?= $class_row['id']; ?>" <?= ($selected_class_id == $class_row['id']) ? 'selected' : ''; ?>>
                                        <?= htmlspecialchars($class_row['class_name']); ?>
                                    </option>
                                <?php endwhile; ?>
                            </select>
                        </div>
                        <div class="col-md-4 mb-3">
                            <button type="submit" class="btn btn-primary mt-4"><i class="fas fa-search"></i> View Attendance</button>
                        </div>
                    </div>
                </form>
            </div>
        </div>

        <!-- Attendance Percentage Display -->
        <div class="card">
            <div class="card-header">
                <h5 class="mb-0"><i class="fas fa-chart-pie"></i> Attendance Percentage</h5>
            </div>
            <div class="card-body">
                <p>Total Days in Month: <strong><?= $total_days; ?></strong></p>
                <p>Holidays: <strong><?= $holidays; ?></strong></p>
                <p>Working Days: <strong><?= $working_days; ?></strong></p>
                <p>Present Days: <strong><?= isset($attendance_summary["$selected_year-$selected_month"]) ? $attendance_summary["$selected_year-$selected_month"]['present'] : 0; ?></strong></p>
                <p>Absent Days: <strong><?= isset($attendance_summary["$selected_year-$selected_month"]) ? $attendance_summary["$selected_year-$selected_month"]['absent'] : 0; ?></strong></p>
                <p>On-Duty Days: <strong><?= isset($attendance_summary["$selected_year-$selected_month"]) ? $attendance_summary["$selected_year-$selected_month"]['on_duty'] : 0; ?></strong></p>
                <p>Attendance Percentage: <strong><?= number_format($attendance_percentage, 2); ?>%</strong></p>
            </div>
        </div>

        <!-- Attendance Records Table -->
        <div class="card">
            <div class="card-header">
                <h5 class="mb-0"><i class="fas fa-table"></i> Attendance Records</h5>
            </div>
            <div class="card-body">
                <table class="table table-striped">
                    <thead>
                        <tr>
                            <th>Date</th>
                            <th>Status</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (count($attendance_records) > 0): ?>
                            <?php foreach ($attendance_records as $record): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($record['date']); ?></td>
                                    <td><?php echo htmlspecialchars($record['status']); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php else: ?>
                            <tr>
                                <td colspan="2" class="text-center">No attendance records found for the selected class, month, and year.</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
        <a href="dashboard.php" class="btn btn-primary mb-4"><i class="fas fa-arrow-left"></i> Back to Dashboard</a>
    </div>
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

<?php
$stmt->close();
$conn->close();
?>